@@ -1,10 +1,19 @@
 /******************************************************************************
 *
-* CHECK_DHCP.C
+* Nagios check_dhcp plugin
 *
-* Program: DHCP plugin for Nagios
 * License: GPL
 * Copyright (c) 2001-2004 Ethan Galstad (nagios@nagios.org)
+* Copyright (c) 2001-2006 Nagios Plugin Development Team
+*
+* Last Modified: $Date: 2006/10/20 06:24:10 $
+*
+* Description:
+*
+* This file contains the check_dhcp plugin
+*
+*  This plugin tests the availability of DHCP servers on a network.
+*
 *
 * License Information:
 *
@@ -22,13 +31,13 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_dhcp.c,v 1.1 2005/09/21 10:06:37 tonvoon Exp $
+* $Id: check_dhcp.c,v 1.6 2006/10/20 06:24:10 opensides Exp $
 *
 *****************************************************************************/
 
 const char *progname = "check_dhcp";
-const char *revision = "$Revision: 1.1 $";
-const char *copyright = "2001-2004";
+const char *revision = "$Revision: 1.6 $";
+const char *copyright = "2001-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -101,16 +110,10 @@ long mac_addr_dlpi( const char *, int, u_char *);
 
 #endif
 
-#define HAVE_GETOPT_H
 
 
 /**** Common definitions ****/
 
-#define STATE_OK          0
-#define STATE_WARNING     1
-#define STATE_CRITICAL    2
-#define STATE_UNKNOWN     -1
-
 #define OK                0
 #define ERROR             -1
 
@@ -157,6 +160,7 @@ typedef struct dhcp_offer_struct{
 
 typedef struct requested_server_struct{
 	struct in_addr server_address;
+	int answered;
 	struct requested_server_struct *next;
         }requested_server;
 
@@ -192,7 +196,7 @@ typedef struct requested_server_struct{
 
 unsigned char client_hardware_address[MAX_DHCP_CHADDR_LENGTH]="";
 
-char network_interface_name[8]="eth0";
+char network_interface_name[IFNAMSIZ]="eth0";
 
 u_int32_t packet_xid=0;
 
@@ -241,7 +245,7 @@ int receive_dhcp_packet(void *,int,int,int,struct sockaddr_in *);
 
 int main(int argc, char **argv){
 	int dhcp_socket;
-	int result;
+	int result = STATE_UNKNOWN;
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
@@ -311,25 +315,25 @@ int get_hardware_address(int sock,char *interface_name){
         mib[3] = AF_LINK;
         mib[4] = NET_RT_IFLIST;
 
-        if ((mib[5] = if_nametoindex(interface_name)) == 0) {
+        if((mib[5] = if_nametoindex(interface_name)) == 0){
                 printf(_("Error: if_nametoindex error - %s.\n"), strerror(errno));
                 exit(STATE_UNKNOWN);
-        }
+		}
 
-        if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0) {
+        if(sysctl(mib, 6, NULL, &len, NULL, 0) < 0){
                 printf(_("Error: Couldn't get hardware address from %s. sysctl 1 error - %s.\n"), interface_name, strerror(errno));
                 exit(STATE_UNKNOWN);
-        }
+		}
 
-        if ((buf = malloc(len)) == NULL) {
+        if((buf = malloc(len)) == NULL){
                 printf(_("Error: Couldn't get hardware address from interface %s. malloc error - %s.\n"), interface_name, strerror(errno));
                 exit(4);
-        }
+		}
 
-        if (sysctl(mib, 6, buf, &len, NULL, 0) < 0) {
+        if(sysctl(mib, 6, buf, &len, NULL, 0) < 0){
                 printf(_("Error: Couldn't get hardware address from %s. sysctl 2 error - %s.\n"), interface_name, strerror(errno));
                 exit(STATE_UNKNOWN);
-        }
+		}
 
         ifm = (struct if_msghdr *)buf;
         sdl = (struct sockaddr_dl *)(ifm + 1);
@@ -345,21 +349,22 @@ int get_hardware_address(int sock,char *interface_name){
 	char *p;
 	int unit;
 
-	for (p = interface_name; *p && isalpha(*p); p++)
+	for(p = interface_name; *p && isalpha(*p); p++)
 		/* no-op */ ;
-	if ( p != '\0' ) {
+	if( p != '\0' ){
 		unit = atoi(p) ;
 		*p = '\0' ;
 		strncat(dev, interface_name, 6) ;
-	} else {
+		} 
+	else{
 		printf(_("Error: can't find unit number in interface_name (%s) - expecting TypeNumber eg lnc0.\n"), interface_name);
 		exit(STATE_UNKNOWN);
-	}
+		}
 	stat = mac_addr_dlpi(dev, unit, client_hardware_address);
-	if (stat != 0) {
+	if(stat != 0){
 		printf(_("Error: can't read MAC address from DLPI streams interface for device %s unit %d.\n"), dev, unit);
 		exit(STATE_UNKNOWN);
-	}
+		}
 
 #elif defined(__hpux__)
 
@@ -368,10 +373,10 @@ int get_hardware_address(int sock,char *interface_name){
 	int unit = 0;
 
 	stat = mac_addr_dlpi(dev, unit, client_hardware_address);
-	if (stat != 0) {
+	if(stat != 0){
 		printf(_("Error: can't read MAC address from DLPI streams interface for device %s unit %d.\n"), dev, unit);
 		exit(STATE_UNKNOWN);
-	}
+		}
 						/* Kompf 2000-2003 */
 
 #else
@@ -379,12 +384,12 @@ int get_hardware_address(int sock,char *interface_name){
 	exit(STATE_UNKNOWN);
 #endif
 
-	if (verbose) { 
+	if(verbose){ 
 		printf(_("Hardware address: "));
 		for (i=0; i<6; ++i)
 			printf("%2.2x", client_hardware_address[i]);
 		printf( "\n");
-	}
+		}
 
 	return OK;
         }
@@ -454,19 +459,19 @@ int send_dhcp_discover(int sock){
 	bzero(&sockaddr_broadcast.sin_zero,sizeof(sockaddr_broadcast.sin_zero));
 
 
-	if (verbose) {
+	if(verbose){
 		printf(_("DHCPDISCOVER to %s port %d\n"),inet_ntoa(sockaddr_broadcast.sin_addr),ntohs(sockaddr_broadcast.sin_port));
 		printf("DHCPDISCOVER XID: %lu (0x%X)\n",ntohl(discover_packet.xid),ntohl(discover_packet.xid));
 		printf("DHCDISCOVER ciaddr:  %s\n",inet_ntoa(discover_packet.ciaddr));
 		printf("DHCDISCOVER yiaddr:  %s\n",inet_ntoa(discover_packet.yiaddr));
 		printf("DHCDISCOVER siaddr:  %s\n",inet_ntoa(discover_packet.siaddr));
 		printf("DHCDISCOVER giaddr:  %s\n",inet_ntoa(discover_packet.giaddr));
-	}
+		}
 
 	/* send the DHCPDISCOVER packet out */
 	send_dhcp_packet(&discover_packet,sizeof(discover_packet),sock,&sockaddr_broadcast);
 
-	if (verbose) 
+	if(verbose) 
 		printf("\n\n");
 
 	return OK;
@@ -479,6 +484,7 @@ int send_dhcp_discover(int sock){
 int get_dhcp_offer(int sock){
 	dhcp_packet offer_packet;
 	struct sockaddr_in source;
+	struct sockaddr_in via;
 	int result=OK;
 	int timeout=1;
 	int responses=0;
@@ -495,36 +501,47 @@ int get_dhcp_offer(int sock){
 		if((current_time-start_time)>=dhcpoffer_timeout)
 			break;
 
-		if (verbose) 
+		if(verbose) 
 			printf("\n\n");
 
 		bzero(&source,sizeof(source));
+		bzero(&via,sizeof(via));
 		bzero(&offer_packet,sizeof(offer_packet));
 
 		result=OK;
 		result=receive_dhcp_packet(&offer_packet,sizeof(offer_packet),sock,dhcpoffer_timeout,&source);
 		
 		if(result!=OK){
-			if (verbose)
+			if(verbose)
 				printf(_("Result=ERROR\n"));
 
 			continue;
 		        }
 		else{
-			if (verbose) 
+			if(verbose) 
 				printf(_("Result=OK\n"));
 
 			responses++;
 		        }
 
-		if (verbose) {
-			printf(_("DHCPOFFER from IP address %s\n"),inet_ntoa(source.sin_addr));
+		/* The "source" is either a server or a relay. */
+		/* Save a copy of "source" into "via" even if it's via itself */
+		memcpy(&via,&source,sizeof(source)) ;
+
+		/* If siaddr is non-zero, set "source" to siaddr */
+		if(offer_packet.siaddr.s_addr != 0L){
+			source.sin_addr.s_addr = offer_packet.siaddr.s_addr ;
+			}
+
+		if(verbose){
+			printf(_("DHCPOFFER from IP address %s"),inet_ntoa(source.sin_addr));
+			printf(_(" via %s\n"),inet_ntoa(via.sin_addr));
 			printf("DHCPOFFER XID: %lu (0x%X)\n",ntohl(offer_packet.xid),ntohl(offer_packet.xid));
-		}
+			}
 
 		/* check packet xid to see if its the same as the one we used in the discover packet */
 		if(ntohl(offer_packet.xid)!=packet_xid){
-			if (verbose)
+			if(verbose)
 				printf(_("DHCPOFFER XID (%lu) did not match DHCPDISCOVER XID (%lu) - ignoring packet\n"),ntohl(offer_packet.xid),packet_xid);
 
 			continue;
@@ -532,42 +549,42 @@ int get_dhcp_offer(int sock){
 
 		/* check hardware address */
 		result=OK;
-		if (verbose)
+		if(verbose)
 			printf("DHCPOFFER chaddr: ");
 
 		for(x=0;x<ETHERNET_HARDWARE_ADDRESS_LENGTH;x++){
-			if (verbose)
+			if(verbose)
 				printf("%02X",(unsigned char)offer_packet.chaddr[x]);
 
 			if(offer_packet.chaddr[x]!=client_hardware_address[x])
 				result=ERROR;
-		}
-		if (verbose)
+			}
+		if(verbose)
 			printf("\n");
 
 		if(result==ERROR){
-			if (verbose) 
+			if(verbose) 
 				printf(_("DHCPOFFER hardware address did not match our own - ignoring packet\n"));
 
 			continue;
 		        }
 
-		if (verbose) {
+		if(verbose){
 			printf("DHCPOFFER ciaddr: %s\n",inet_ntoa(offer_packet.ciaddr));
 			printf("DHCPOFFER yiaddr: %s\n",inet_ntoa(offer_packet.yiaddr));
 			printf("DHCPOFFER siaddr: %s\n",inet_ntoa(offer_packet.siaddr));
 			printf("DHCPOFFER giaddr: %s\n",inet_ntoa(offer_packet.giaddr));
-		}
+			}
 
 		add_dhcp_offer(source.sin_addr,&offer_packet);
 
 		valid_responses++;
 	        }
 
-	if (verbose) {
+	if(verbose){
 		printf(_("Total responses seen on the wire: %d\n"),responses);
 		printf(_("Valid responses for this machine: %d\n"),valid_responses);
-	}
+		}
 
 	return OK;
         }
@@ -581,7 +598,7 @@ int send_dhcp_packet(void *buffer, int buffer_size, int sock, struct sockaddr_in
 
 	result=sendto(sock,(char *)buffer,buffer_size,0,(struct sockaddr *)dest,sizeof(*dest));
 
-	if (verbose) 
+	if(verbose) 
 		printf(_("send_dhcp_packet result: %d\n"),result);
 
 	if(result<0)
@@ -610,7 +627,7 @@ int receive_dhcp_packet(void *buffer, int buffer_size, int sock, int timeout, st
 
         /* make sure some data has arrived */
         if(!FD_ISSET(sock,&readfds)){
-		if (verbose)
+		if(verbose)
                 	printf(_("No (more) data received\n"));
                 return ERROR;
                 }
@@ -622,24 +639,24 @@ int receive_dhcp_packet(void *buffer, int buffer_size, int sock, int timeout, st
 		bzero(&source_address,sizeof(source_address));
 		address_size=sizeof(source_address);
                 recv_result=recvfrom(sock,(char *)buffer,buffer_size,MSG_PEEK,(struct sockaddr *)&source_address,&address_size);
-		if (verbose)
+		if(verbose)
 			printf("recv_result_1: %d\n",recv_result);
                 recv_result=recvfrom(sock,(char *)buffer,buffer_size,0,(struct sockaddr *)&source_address,&address_size);
-		if (verbose)
+		if(verbose)
 			printf("recv_result_2: %d\n",recv_result);
 
                 if(recv_result==-1){
-			if (verbose) {
+			if(verbose){
 				printf(_("recvfrom() failed, "));
 				printf("errno: (%d) -> %s\n",errno,strerror(errno));
-			}
+				}
                         return ERROR;
                         }
 		else{
-			if (verbose) {
+			if(verbose){
 				printf(_("receive_dhcp_packet() result: %d\n"),recv_result);
 				printf(_("receive_dhcp_packet() source: %s\n"),inet_ntoa(source_address.sin_addr));
-			}
+				}
 
 			memcpy(address,&source_address,sizeof(source_address));
 			return OK;
@@ -671,7 +688,7 @@ int create_dhcp_socket(void){
 		exit(STATE_UNKNOWN);
 	        }
 
-	if (verbose)
+	if(verbose)
 		printf("DHCP socket: %d\n",sock);
 
         /* set the reuse address flag so we don't get errors when restarting */
@@ -727,13 +744,14 @@ int add_requested_server(struct in_addr server_address){
 		return ERROR;
 
 	new_server->server_address=server_address;
+	new_server->answered=FALSE;
 
 	new_server->next=requested_server_list;
 	requested_server_list=new_server;
 
 	requested_servers++;
 
-	if (verbose)
+	if(verbose)
 		printf(_("Requested server address: %s\n"),inet_ntoa(new_server->server_address));
 
 	return OK;
@@ -766,32 +784,29 @@ int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 		/* get option length */
 		option_length=offer_packet->options[x++];
 
-		if (verbose) 
+		if(verbose) 
 			printf("Option: %d (0x%02X)\n",option_type,option_length);
 
 		/* get option data */
-        if(option_type==DHCP_OPTION_LEASE_TIME) {
-            memcpy(&dhcp_lease_time, &offer_packet->options[x],
-                sizeof(dhcp_lease_time));
-            dhcp_lease_time = ntohl(dhcp_lease_time);
-        }
-        if(option_type==DHCP_OPTION_RENEWAL_TIME) {
-            memcpy(&dhcp_renewal_time, &offer_packet->options[x],
-                sizeof(dhcp_renewal_time));
-            dhcp_renewal_time = ntohl(dhcp_renewal_time);
-        }
-        if(option_type==DHCP_OPTION_REBINDING_TIME) {
-            memcpy(&dhcp_rebinding_time, &offer_packet->options[x],
-                sizeof(dhcp_rebinding_time));
-            dhcp_rebinding_time = ntohl(dhcp_rebinding_time);
-        }
+		if(option_type==DHCP_OPTION_LEASE_TIME){
+			memcpy(&dhcp_lease_time, &offer_packet->options[x],sizeof(dhcp_lease_time));
+			dhcp_lease_time = ntohl(dhcp_lease_time);
+			}
+		if(option_type==DHCP_OPTION_RENEWAL_TIME){
+			memcpy(&dhcp_renewal_time, &offer_packet->options[x],sizeof(dhcp_renewal_time));
+			dhcp_renewal_time = ntohl(dhcp_renewal_time);
+			}
+		if(option_type==DHCP_OPTION_REBINDING_TIME){
+			memcpy(&dhcp_rebinding_time, &offer_packet->options[x],sizeof(dhcp_rebinding_time));
+			dhcp_rebinding_time = ntohl(dhcp_rebinding_time);
+			}
 
 		/* skip option data we're ignoring */
 		else
 			for(y=0;y<option_length;y++,x++);
 	        }
 
-	if (verbose) {
+	if(verbose){
 		if(dhcp_lease_time==DHCP_INFINITE_TIME)
 			printf(_("Lease Time: Infinite\n"));
 		else
@@ -803,7 +818,7 @@ int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 		if(dhcp_rebinding_time==DHCP_INFINITE_TIME)
 			printf(_("Rebinding Time: Infinite\n"));
 		printf(_("Rebinding Time: %lu seconds\n"),(unsigned long)dhcp_rebinding_time);
-	}
+		}
 
 	new_offer=(dhcp_offer *)malloc(sizeof(dhcp_offer));
 
@@ -817,10 +832,10 @@ int add_dhcp_offer(struct in_addr source,dhcp_packet *offer_packet){
 	new_offer->rebinding_time=dhcp_rebinding_time;
 
 
-	if (verbose) {
+	if(verbose){
 		printf(_("Added offer from server @ %s"),inet_ntoa(new_offer->server_address));
 		printf(_(" of IP address %s\n"),inet_ntoa(new_offer->offered_address));
-	}
+		}
 
 	/* add new offer to head of list */
 	new_offer->next=dhcp_offer_list;
@@ -885,11 +900,17 @@ int get_results(void){
 
 				/* see if the servers we wanted a response from talked to us or not */
 				if(!memcmp(&temp_offer->server_address,&temp_server->server_address,sizeof(temp_server->server_address))){
-	if (verbose) {
-					printf(_("DHCP Server Match: Offerer=%s"),inet_ntoa(temp_offer->server_address));
-					printf(_(" Requested=%s\n"),inet_ntoa(temp_server->server_address));
-	}				       
-					requested_responses++;
+					if(verbose){
+						printf(_("DHCP Server Match: Offerer=%s"),inet_ntoa(temp_offer->server_address));
+						printf(_(" Requested=%s"),inet_ntoa(temp_server->server_address));
+						if(temp_server->answered) 
+							printf(_(" (duplicate)"));
+						printf(_("\n"));
+						}
+					if(temp_server->answered == FALSE){
+						requested_responses++;
+						temp_server->answered=TRUE;
+						}
 				        }
 		                }
 		        }
@@ -921,8 +942,14 @@ int get_results(void){
 	else if(request_specific_address==TRUE && received_requested_address==FALSE)
 		result=STATE_WARNING;
 
-
-	printf("DHCP %s: ",(result==STATE_OK)?"ok":"problem");
+	if(result==0)               /* garrett honeycutt 2005 */
+		printf("OK: ");
+	else if(result==1)
+		printf("WARNING: ");
+	else if(result==2)
+		printf("CRITICAL: ");
+	else if(result==3)
+		printf("UNKNOWN: ");
 
 	/* we didn't receive any DHCPOFFERs */
 	if(dhcp_offer_list==NULL){
@@ -976,7 +1003,6 @@ int call_getopt(int argc, char **argv){
 	int i=0;
 	struct in_addr ipaddress;
 
-#ifdef HAVE_GETOPT_H
 	int option_index = 0;
 	static struct option long_options[] =
 	{ 
@@ -989,14 +1015,9 @@ int call_getopt(int argc, char **argv){
 		{"help",           no_argument,      0,'h'},
 		{0,0,0,0}
 	};
-#endif
 
 	while(1){
-#ifdef HAVE_GETOPT_H
 		c=getopt_long(argc,argv,"+hVvt:s:r:t:i:",long_options,&option_index);
-#else
-		c=getopt(argc,argv,"+?hVvt:s:r:t:i:");
-#endif
 
 		i++;
 
@@ -1086,107 +1107,112 @@ int validate_arguments(void){
 	return OK;
         }
 
-#if defined(__sun__) || defined(__solaris__) || defined(__hpux__)
 
-						/* Kompf 2000-2003	see ACKNOWLEDGEMENTS */
+#if defined(__sun__) || defined(__solaris__) || defined(__hpux__)
+/* Kompf 2000-2003	see ACKNOWLEDGEMENTS */
 
 /* get a message from a stream; return type of message */
-static int get_msg(int fd)
-{
-    int flags = 0;
-    int res, ret;
-    ctl_area[0] = 0;
-    dat_area[0] = 0;
-    ret = 0;
-    res = getmsg(fd, &ctl, &dat, &flags);
+static int get_msg(int fd){
+	int flags = 0;
+	int res, ret;
+	ctl_area[0] = 0;
+	dat_area[0] = 0;
+	ret = 0;
+	res = getmsg(fd, &ctl, &dat, &flags);
 
-    if(res < 0) {
-        if(errno == EINTR) {
-            return(GOT_INTR);
-        } else {
-	    printf("%s\n", "get_msg FAILED.");
-            return(GOT_ERR);
-        }
-    }
-    if(ctl.len > 0) {
-        ret |= GOT_CTRL;
-    }
-    if(dat.len > 0) {
-        ret |= GOT_DATA;
-    }
-    return(ret);
-}
+	if(res < 0){
+		if(errno == EINTR){
+			return(GOT_INTR);
+			}
+		else{
+			printf("%s\n", "get_msg FAILED.");
+			return(GOT_ERR);
+			}
+		}
+	if(ctl.len > 0){
+		ret |= GOT_CTRL;
+		}
+	if(dat.len > 0){
+		ret |= GOT_DATA;
+		}
+
+	return(ret);
+	}
 
 /* verify that dl_primitive in ctl_area = prim */
-static int check_ctrl(int prim)
-{
-    dl_error_ack_t *err_ack = (dl_error_ack_t *)ctl_area;
-    if(err_ack->dl_primitive != prim) {
-	printf(_("Error: DLPI stream API failed to get MAC in check_ctrl: %s.\n"), strerror(errno));
-        exit(STATE_UNKNOWN);
-    }
-    return 0;
-}
+static int check_ctrl(int prim){
+	dl_error_ack_t *err_ack = (dl_error_ack_t *)ctl_area;
+
+	if(err_ack->dl_primitive != prim){
+		printf(_("Error: DLPI stream API failed to get MAC in check_ctrl: %s.\n"), strerror(errno));
+		exit(STATE_UNKNOWN);
+		}
+
+	return 0;
+	}
 
 /* put a control message on a stream */
-static int put_ctrl(int fd, int len, int pri)
-{
-    ctl.len = len;
-    if(putmsg(fd, &ctl, 0, pri) < 0) {
-	printf(_("Error: DLPI stream API failed to get MAC in put_ctrl/putmsg(): %s.\n"), strerror(errno));
-        exit(STATE_UNKNOWN);
-    }
-    return  0;
-}
+static int put_ctrl(int fd, int len, int pri){
+
+	ctl.len = len;
+	if(putmsg(fd, &ctl, 0, pri) < 0){
+		printf(_("Error: DLPI stream API failed to get MAC in put_ctrl/putmsg(): %s.\n"), strerror(errno));
+		exit(STATE_UNKNOWN);
+		}
+
+	return  0;
+	}
 
 /* put a control + data message on a stream */
-static int put_both(int fd, int clen, int dlen, int pri)
-{
-    ctl.len = clen;
-    dat.len = dlen;
-    if(putmsg(fd, &ctl, &dat, pri) < 0) {
-	printf(_("Error: DLPI stream API failed to get MAC in put_both/putmsg().\n"), strerror(errno));
-        exit(STATE_UNKNOWN);
-    }
-    return  0;
-}
+static int put_both(int fd, int clen, int dlen, int pri){
+
+	ctl.len = clen;
+	dat.len = dlen;
+	if(putmsg(fd, &ctl, &dat, pri) < 0){
+		printf(_("Error: DLPI stream API failed to get MAC in put_both/putmsg().\n"), strerror(errno));
+		exit(STATE_UNKNOWN);
+		}
+
+	return  0;
+	}
 
 /* open file descriptor and attach */
-static int dl_open(const char *dev, int unit, int *fd)
-{
-    dl_attach_req_t *attach_req = (dl_attach_req_t *)ctl_area;
-    if((*fd = open(dev, O_RDWR)) == -1) {
-	printf(_("Error: DLPI stream API failed to get MAC in dl_attach_req/open(%s..): %s.\n"), dev, strerror(errno));
-        exit(STATE_UNKNOWN);
-    }
-    attach_req->dl_primitive = DL_ATTACH_REQ;
-    attach_req->dl_ppa = unit;
-    put_ctrl(*fd, sizeof(dl_attach_req_t), 0);
-    get_msg(*fd);
-    return check_ctrl(DL_OK_ACK);
-}
+static int dl_open(const char *dev, int unit, int *fd){
+	dl_attach_req_t *attach_req = (dl_attach_req_t *)ctl_area;
+
+	if((*fd = open(dev, O_RDWR)) == -1){
+		printf(_("Error: DLPI stream API failed to get MAC in dl_attach_req/open(%s..): %s.\n"), dev, strerror(errno));
+		exit(STATE_UNKNOWN);
+		}
+	attach_req->dl_primitive = DL_ATTACH_REQ;
+	attach_req->dl_ppa = unit;
+	put_ctrl(*fd, sizeof(dl_attach_req_t), 0);
+	get_msg(*fd);
+	return check_ctrl(DL_OK_ACK);
+	}
 
 /* send DL_BIND_REQ */
-static int dl_bind(int fd, int sap, u_char *addr)
-{
-    dl_bind_req_t *bind_req = (dl_bind_req_t *)ctl_area;
-    dl_bind_ack_t *bind_ack = (dl_bind_ack_t *)ctl_area;
-    bind_req->dl_primitive = DL_BIND_REQ;
-    bind_req->dl_sap = sap;
-    bind_req->dl_max_conind = 1;
-    bind_req->dl_service_mode = DL_CLDLS;
-    bind_req->dl_conn_mgmt = 0;
-    bind_req->dl_xidtest_flg = 0;
-    put_ctrl(fd, sizeof(dl_bind_req_t), 0);
-    get_msg(fd);
-    if (GOT_ERR == check_ctrl(DL_BIND_ACK)) {
-	printf(_("Error: DLPI stream API failed to get MAC in dl_bind/check_ctrl(): %s.\n"), strerror(errno));
-        exit(STATE_UNKNOWN);
-    }
-    bcopy((u_char *)bind_ack + bind_ack->dl_addr_offset, addr,
-        bind_ack->dl_addr_length);
-    return 0;
-}
+static int dl_bind(int fd, int sap, u_char *addr){
+	dl_bind_req_t *bind_req = (dl_bind_req_t *)ctl_area;
+	dl_bind_ack_t *bind_ack = (dl_bind_ack_t *)ctl_area;
+
+	bind_req->dl_primitive = DL_BIND_REQ;
+	bind_req->dl_sap = sap;
+	bind_req->dl_max_conind = 1;
+	bind_req->dl_service_mode = DL_CLDLS;
+	bind_req->dl_conn_mgmt = 0;
+	bind_req->dl_xidtest_flg = 0;
+	put_ctrl(fd, sizeof(dl_bind_req_t), 0);
+	get_msg(fd);
+	if (GOT_ERR == check_ctrl(DL_BIND_ACK)){
+		printf(_("Error: DLPI stream API failed to get MAC in dl_bind/check_ctrl(): %s.\n"), strerror(errno));
+		exit(STATE_UNKNOWN);
+		}
+	bcopy((u_char *)bind_ack + bind_ack->dl_addr_offset, addr,
+	      bind_ack->dl_addr_length);
+
+	return 0;
+	}
 
 /***********************************************************************
  * interface:
@@ -1200,23 +1226,22 @@ static int dl_bind(int fd, int sap, u_char *addr)
  *
  ***********************************************************************/
 
-long mac_addr_dlpi( const char *dev, int unit, u_char  *addr) {
-
+long mac_addr_dlpi( const char *dev, int unit, u_char  *addr){
 	int fd;
 	u_char mac_addr[25];
 
-	if (GOT_ERR != dl_open(dev, unit, &fd)) {
-        	if (GOT_ERR != dl_bind(fd, INSAP, mac_addr)) {
+	if(GOT_ERR != dl_open(dev, unit, &fd)){
+        	if(GOT_ERR != dl_bind(fd, INSAP, mac_addr)){
                 	bcopy( mac_addr, addr, 6);
                 	return 0;
-                }
-	}
+			}
+		}
         close(fd);
+
 	return -1;
-}
-
-						/* Kompf 2000-2003 */
+	}
 
+/* Kompf 2000-2003 */
 #endif
 
 
@@ -1225,37 +1250,40 @@ void print_help(void){
 
 	print_revision(progname,revision);
 
-	printf("Copyright (c) 2001-2004 Ethan Galstad (nagios@nagios.org)\n\n");
+	printf("Copyright (c) 2001-2004 Ethan Galstad (nagios@nagios.org)\n");
 	printf (COPYRIGHT, copyright, email);
 	
-	printf(_("This plugin tests the availability of DHCP servers on a network.\n\n"));
+	printf("%s\n", _("This plugin tests the availability of DHCP servers on a network."));
+
+  printf ("\n\n");
 
 	print_usage();
 
-	printf(_("\
- -s, --serverip=IPADDRESS\n\
-   IP address of DHCP server that we must hear from\n\
- -r, --requestedip=IPADDRESS\n\
-   IP address that should be offered by at least one DHCP server\n\
- -t, --timeout=INTEGER\n\
-   Seconds to wait for DHCPOFFER before timeout occurs\n\
- -i, --interface=STRING\n\
-   Interface to to use for listening (i.e. eth0)\n\
- -v, --verbose\n\
-   Print extra information (command-line use only)\n\
- -h, --help\n\
-   Print detailed help screen\n\
- -V, --version\n\
-   Print version information\n"));
-}
+	printf (_(UT_HELP_VRSN));
+
+	printf (_(UT_VERBOSE));
+
+	printf (" %s\n", "-s, --serverip=IPADDRESS");
+  printf ("    %s\n", _("IP address of DHCP server that we must hear from"));
+  printf (" %s\n", "-r, --requestedip=IPADDRESS");
+  printf ("    %s\n", _("IP address that should be offered by at least one DHCP server"));
+  printf (" %s\n", "-t, --timeout=INTEGER");
+  printf ("    %s\n", _("Seconds to wait for DHCPOFFER before timeout occurs"));
+  printf (" %s\n", "-i, --interface=STRING");
+  printf ("    %s\n", _("Interface to to use for listening (i.e. eth0)"));
+
+	return;
+	}
 
 
-void print_usage(void)
-{
-	printf("\
-Usage: %s [-s serverip] [-r requestedip] [-t timeout] [-i interface]\n\
-                  [-v]",progname);
-}
+void
+print_usage(void){
+	
+  printf (_("Usage:"));
+  printf ("%s [-s serverip] [-r requestedip] [-t timeout] [-i interface] [-v]\n",progname);
+  
+	return;
+	}
 
 
 
