@@ -22,7 +22,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: check_mailq.pl,v 1.6 2005/04/14 04:13:13 seanius Exp $
+# $Id: check_mailq.pl,v 1.7 2006/07/05 13:45:57 tonvoon Exp $
 #
 ############################################################################
 
@@ -186,12 +186,10 @@ if ($mailq eq "sendmail") {
 	## close mailq
 
 	close (MAILQ); 
-	# declare an error if we also get a non-zero return code from mailq
-	# unless already set to critical
+
 	if ( $? ) {
-		$state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
-		print "STDERR $?: $!\n" if $verbose;
-		$msg = "$state: (stderr)\n";
+		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
+		exit $ERRORS{CRITICAL};
 	}
 
 	## shut off the alarm
@@ -318,12 +316,10 @@ elsif ( $mailq eq "postfix" ) {
 
         # close qmail-qstat
         close MAILQ;
-        # declare an error if we also get a non-zero return code from mailq
-        # unless already set to critical
+
         if ( $? ) {
-                $state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
-                print "STDERR $?: $!\n" if $verbose;
-                $msg = "$state: (stderr)\n";
+		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
+		exit $ERRORS{CRITICAL};
         }
 
         ## shut off the alarm
@@ -401,12 +397,10 @@ elsif ( $mailq eq "qmail" ) {
 
 	# close qmail-qstat
 	close MAILQ;
-	# declare an error if we also get a non-zero return code from mailq
-	# unless already set to critical
+
 	if ( $? ) {
-		$state = $state == $ERRORS{"CRITICAL"} ? $ERRORS{"CRITICAL"} : $ERRORS{"WARNING"}  ;
-		print "STDERR $?: $!\n" if $verbose;
-		$msg = "$state: (stderr)\n";
+		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
+		exit $ERRORS{CRITICAL};
 	}
 
 	## shut off the alarm
@@ -490,6 +484,11 @@ elsif ( $mailq eq "exim" ) {
 	    }
 	}
 	close(MAILQ) ;
+
+	if ( $? ) {
+		print "CRITICAL: Error code ".($?>>8)." returned from $utils::PATH_TO_MAILQ",$/;
+		exit $ERRORS{CRITICAL};
+	}
 	if ($msg_q < $opt_w) {
 		$msg = "OK: mailq ($msg_q) is below threshold ($opt_w/$opt_c)";
 		$state = $ERRORS{'OK'};
@@ -523,7 +522,7 @@ sub process_arguments(){
 		 );
 
 	if ($opt_V) {
-		print_revision($PROGNAME,'$Revision: 1.6 $ ');
+		print_revision($PROGNAME,'$Revision: 1.7 $ ');
 		exit $ERRORS{'OK'};
 	}
 
@@ -581,7 +580,7 @@ sub print_usage () {
 }
 
 sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1.6 $');
+	print_revision($PROGNAME,'$Revision: 1.7 $');
 	print "Copyright (c) 2002 Subhendu Ghosh/Carlos Canau/Benjamin Schmid\n";
 	print "\n";
 	print_usage();
