@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-
+#
 # (c)1999 Ian Cass, Knowledge Matters Ltd.
 # Read the GNU copyright stuff for all the legalese
 #
@@ -7,7 +7,7 @@
 # be installed on the system, however since it's part of the ntp suite, you 
 # should already have it installed.
 #
-# $Id: check_ntp.pl,v 1.29 2005/05/25 14:05:41 sghosh Exp $
+# $Id: check_ntp.pl,v 1.31 2005/11/30 00:49:47 harpermann Exp $
 #
 # Nothing clever done in this program - its a very simple bare basics hack to
 # get the job done.
@@ -97,7 +97,7 @@ GetOptions
 	 "H=s" => \$opt_H, "hostname=s" => \$opt_H);
 
 if ($opt_V) {
-	print_revision($PROGNAME,'$Revision: 1.29 $ ');
+	print_revision($PROGNAME,'$Revision: 1.31 $ ');
 	exit $ERRORS{'OK'};
 }
 
@@ -200,13 +200,15 @@ elsif ($ipv6) {
 ###
 
 if (!open (NTPDATE, $ntpdate . " -q $host 2>&1 |")) {
-	print "Could not open ntpdate\n";
+	print "Could not open $ntpdate: $!\n";
 	exit $ERRORS{"UNKNOWN"};
 }
 
+my $out;
 while (<NTPDATE>) {
 	#print if ($verbose);  # noop
 	$msg = $_ unless ($msg);
+	$out .= "$_ ";
 	
 	if (/stratum\s(\d+)/) {
 		$stratum = $1;
@@ -241,8 +243,11 @@ while (<NTPDATE>) {
 	}
 
 }
+$out =~ s/\n//g;
+close (NTPDATE) || 
+    die $! ? "$out - Error closing $ntpdate pipe: $!"
+           : "$out - Exit status: $? from $ntpdate\n";
 
-close (NTPDATE); 
 # declare an error if we also get a non-zero return code from ntpdate
 # unless already set to critical
 if ( $? && !$ignoreret ) {
@@ -293,7 +298,7 @@ if ($have_ntpq) {
 			}
 			
 			# match sys.peer or pps.peer
-			if (/^(\*|o)([-0-9.\s]+)\s+([-0-9A-Za-z_().]+)\s+([-0-9.]+)\s+([lumb-]+)\s+([-0-9hm.]+)\s+([-0-9.mh]+)\s+([-0-9.]+)\s+([-0-9.]+)\s+([-0-9.]+)\s+([-0-9.]+)/) {
+			if (/^(\*|o)(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)/) {
 				$syspeer = $2;
 				$stratum = $4;
 				$jitter = $11;
@@ -313,7 +318,9 @@ if ($have_ntpq) {
 			}
 			
 		}
-		close NTPQ;
+		close NTPQ ||
+            die $! ? "Error closing $ntpq pipe: $!"
+                   : "Exit status: $? from $ntpq\n";
 
 		# if we did not match sys.peer or pps.peer but matched # candidates only
 		# generate a warning 
@@ -436,7 +443,7 @@ sub print_usage () {
 }
 
 sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1.29 $');
+	print_revision($PROGNAME,'$Revision: 1.31 $');
 	print "Copyright (c) 2003 Bo Kersey/Karl DeBisschop\n";
 	print "\n";
 	print_usage();
