@@ -1,26 +1,42 @@
 /******************************************************************************
+*
+* Nagios check_dummy plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 00:25:16 $
+*
+* Description:
+*
+* This file contains the check_dummy plugin
+*
+*  This plugin will simply return the state corresponding to the numeric value
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_dummy.c,v 1.15 2005/11/14 00:51:44 opensides Exp $
+ $Id: check_dummy.c,v 1.17 2006/10/19 00:25:16 opensides Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_dummy";
-const char *revision = "$Revision: 1.15 $";
-const char *copyright = "1999-2005";
+const char *revision = "$Revision: 1.17 $";
+const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -90,11 +106,9 @@ print_help (void)
   printf ("Copyright (c) 1999 Ethan Galstad <nagios@nagios.org>\n");
   printf (COPYRIGHT, copyright, email);
 
-  printf (_("This plugin will simply return the state corresponding to the numeric value"));
+  printf ("%s\n", _("This plugin will simply return the state corresponding to the numeric value"));
  
-  printf ("\n");
- 
-  printf (_("of the <state> argument with optional text"));
+  printf ("%s\n", _("of the <state> argument with optional text"));
 
   printf ("\n\n");
   
