@@ -1,45 +1,46 @@
-/*
- *  check_ide-smart v.1 - hacked version of ide-smart for Nagios
- *  Copyright (C) 2000 Robert Dale <rdale@digital-mission.com>
+/******************************************************************************
+* Nagios check_ide_smart plugin
+*
+* License: GPL
+*
+*  ide-smart 1.3 - IDE S.M.A.R.T. checking tool
+*  Copyright (C)  1998-1999 Ragnar Hojland Espinosa <ragnar@lightside.dhis.org>
+*                 1998      Gadi Oxman <gadio@netvision.net.il>
+* 
+* Copyright (c) 2000 Robert Dale <rdale@digital-mission.com>
+* Copyright (c) 2000-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 00:25:16 $
+*
+* Description:
+*
+* This file contains the check_ide_smart plugin
+*
+*  This plugin checks a local hard drive with the (Linux specific) SMART interface
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  Nagios - http://www.nagios.org
- *
- *  Notes:
- *	   ide-smart has the same functionality as before. Some return
- *	   values were changed, otherwise the --nagios option was added.
- *
- *	   Run with:  check_ide-smart --nagios [-d] <DRIVE>
- *	   Where DRIVE is an IDE drive, ie. /dev/hda, /dev/hdb, /dev/hdc
- *
- *	     - Returns 0 on no errors
- *	     - Returns 1 on advisories
- *	     - Returns 2 on prefailure
- *	     - Returns -1 not too often
- *
- *  ide-smart 1.3 - IDE S.M.A.R.T. checking tool
- *  Copyright (C) 1998-1999 Ragnar Hojland Espinosa <ragnar@lightside.dhis.org>
- *		  1998	    Gadi Oxman <gadio@netvision.net.il>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- * $Id: check_ide_smart.c,v 1.10 2005/02/02 06:42:18 stanleyhopcroft Exp $
+ * $Id: check_ide_smart.c,v 1.12 2006/10/19 00:25:16 opensides Exp $
  */
 
 const char *progname = "check_ide_smart";
-const char *revision = "$Revision: 1.10 $";
-const char *copyright = "2000-2004";
+const char *revision = "$Revision: 1.12 $";
+const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 	
 #include "common.h"
@@ -501,30 +502,46 @@ print_help (void)
 	printf ("(C) 1999 Ragnar Hojland Espinosa <ragnar@lightside.dhis.org>\n");
 	printf (COPYRIGHT, copyright, email);
 
-	printf(_("This plugin checks a local hard drive with the (Linux specific) SMART interface [http://smartlinux.sourceforge.net/smart/index.php].\n\n"));
+	printf (_("This plugin checks a local hard drive with the (Linux specific) SMART interface [http://smartlinux.sourceforge.net/smart/index.php]."));
+ 
+  printf ("\n\n");
+  
+  print_usage ();
+
+  printf (_(UT_HELP_VRSN));
 	
-	printf ("\
-Usage: %s [OPTION] [DEVICE]\n\
- -d, --device=DEVICE\n\
-    Select device DEVICE\n\
-    Note: if the device is selected with this option, _no_ other options are accepted\n\
- -i, --immediate\n\
-    Perform immediately offline tests\n\
- -q, --quiet-check\n\
-    Returns the number of failed tests\n\
- -1, --auto-on\n\
-    Turn on automatic offline tests\n\
- -0, --auto-off\n\
-    Turn off automatic offline tests\n\
- -n, --nagios\n\
-    Output suitable for Nagios\n", progname);
+  printf (" %s\n", "-d, --device=DEVICE");
+  printf ("    %s\n", _("Select device DEVICE"));
+  printf ("    %s\n", _("Note: if the device is selected with this option, _no_ other options are accepted"));
+  printf (" %s\n", "-i, --immediate");
+  printf ("    %s\n", _("Perform immediately offline tests"));
+  printf (" %s\n", "-q, --quiet-check");
+  printf ("    %s\n", _("Returns the number of failed tests"));
+  printf (" %s\n", "-1, --auto-on");
+  printf ("    %s\n", _("Turn on automatic offline tests"));
+  printf (" %s\n", "-0, --auto-off");
+  printf ("    %s\n", _("Turn off automatic offline tests"));
+  printf (" %s\n", "-n, --nagios");
+  printf ("    %s\n", _("Output suitable for Nagios\n"));
+  printf (_(UT_SUPPORT));
 }
 
+ /* todo : add to the long nanual as example
+ *
+ *     Run with:  check_ide-smart --nagios [-d] <DRIVE>
+ *     Where DRIVE is an IDE drive, ie. /dev/hda, /dev/hdb, /dev/hdc
+ *
+ *       - Returns 0 on no errors
+ *       - Returns 1 on advisories
+ *       - Returns 2 on prefailure
+ *       - Returns -1 not too often
+ */
+
 
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s [-d <device>] [-i <immediate>] [-q quiet] [-1 <auto-on>]\n\
-                        [-O <auto-off>] [-n <nagios>]\n", progname);
+	printf (_("Usage:");
+  printf ("%s [-d <device>] [-i <immediate>] [-q quiet] [-1 <auto-on>]",progname);
+  pritnf (" [-O <auto-off>] [-n <nagios>]\n");
 }
