@@ -1,27 +1,40 @@
 /******************************************************************************
+*
+* Nagios check_ldap plugin
+*
+* License: GPL
+* Copyright (c) 2000-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/22 22:24:27 $
+*
+* Description:
+*
+* This file contains the check_ldap plugin
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_ldap.c,v 1.30 2004/12/25 23:17:44 opensides Exp $
+ $Id: check_ldap.c,v 1.33 2006/10/22 22:24:27 opensides Exp $
  
 ******************************************************************************/
 
 /* progname may be check_ldaps */
 char *progname = "check_ldap";
-const char *revision = "$Revision: 1.30 $";
-const char *copyright = "2000-2004";
+const char *revision = "$Revision: 1.33 $";
+const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -351,6 +364,8 @@ print_help (void)
 	printf ("Copyright (c) 1999 Didi Rieder (adrieder@sbox.tu-graz.ac.at)\n");
 	printf (COPYRIGHT, copyright, email);
 
+  printf ("\n\n");
+  
 	print_usage ();
 
 	printf (_(UT_HELP_VRSN));
@@ -359,24 +374,21 @@ print_help (void)
 
 	printf (_(UT_IPv46));
 
-	printf (_("\
- -a [--attr]\n\
-    ldap attribute to search (default: \"(objectclass=*)\"\n\
- -b [--base]\n\
-    ldap base (eg. ou=my unit, o=my org, c=at)\n\
- -D [--bind]\n\
-    ldap bind DN (if required)\n\
- -P [--pass]\n\
-    ldap password (if required)\n"));
+	printf (" %s\n", "-a [--attr]");
+  printf ("    %s\n", _("ldap attribute to search (default: \"(objectclass=*)\""));
+  printf (" %s\n", "-b [--base]");
+  printf ("    %s\n", _("ldap base (eg. ou=my unit, o=my org, c=at"));
+  printf (" %s\n," "-D [--bind]");
+  printf ("    %s\n", _("ldap bind DN (if required)"));
+  printf (" %s\n," "-P [--pass]");
+  printf ("    %s\n", _("ldap password (if required)"));
 
 #ifdef HAVE_LDAP_SET_OPTION
-	printf (_("\
- -2 [--ver2]\n\
-     use ldap protocol version 2\n\
- -3 [--ver3]\n\
-    use ldap protocol version 3\n\
-    (default protocol version: %d)\n"),
-	        DEFAULT_PROTOCOL);
+	printf (" %s\n", "-2 [--ver2]");
+  printf ("    %s\n", _("use ldap protocol version 2"));
+  printf (" %s\n", "-3 [--ver3]");
+  printf ("    %s\n", _("use ldap protocol version 3"));
+  printf ("(default protocol version: %d)", DEFAULT_PROTOCOL);
 #endif
 
 	printf (_(UT_WARN_CRIT));
@@ -388,16 +400,17 @@ print_help (void)
 	printf (_(UT_SUPPORT));
 }
 
+/* todo
+* add option -4 and -6 to the long manual
+*
+*/
 
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -H <host> -b <base_dn> [-p <port>] [-a <attr>] [-D <binddn>]\n\
-                  [-P <password>] [-w <warn_time>] [-c <crit_time>]\n\
-									[-t timeout]%s\n",
-//(Note: all times are in seconds.)\n",
-	        progname,
+  printf (_("Usage:"));
+	printf (" %s -H <host> -b <base_dn> [-p <port>] [-a <attr>] [-D <binddn>]",progname);
+  printf ("[-P <password>] [-w <warn_time>] [-c <crit_time>] [-t timeout]\n",
 #ifdef HAVE_LDAP_SET_OPTION
 			" [-2|-3] [-4|-6]"
 #else
