@@ -1,26 +1,43 @@
 /******************************************************************************
+*
+* Nagios check_mrtg plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/20 07:39:35 $
+*
+* Description:
+*
+* This file contains the check_mrtg plugin
+*
+*  This plugin will check either the average or maximum value of one of the
+*  two variables recorded in an MRTG log file.
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_mrtg.c,v 1.25 2005/10/13 09:58:12 seanius Exp $
+ $Id: check_mrtg.c,v 1.28 2006/10/20 07:39:35 opensides Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_mrtg";
-const char *revision =  "$Revision: 1.25 $";
-const char *copyright = "1999-2004";
+const char *revision =  "$Revision: 1.28 $";
+const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -305,55 +322,52 @@ print_help (void)
 	printf ("Copyright (c) 1999 Ethan Galstad <nagios@nagios.org>\n");
 	printf (COPYRIGHT, copyright, email);
 
-	printf(_("\
-This plugin will check either the average or maximum value of one of the\n\
-two variables recorded in an MRTG log file.\n\n"));
+	printf ("%s\n", _("This plugin will check either the average or maximum value of one of the"));
+  printf ("%s\n", _("two variables recorded in an MRTG log file."));
 
+  printf ("\n\n");
+  
 	print_usage ();
 
 	printf (_(UT_HELP_VRSN));
 
-	printf (_("\
- -F, --logfile=FILE\n\
-   The MRTG log file containing the data you want to monitor\n\
- -e, --expires=MINUTES\n\
-   Minutes before MRTG data is considered to be too old\n\
- -a, --aggregation=AVG|MAX\n\
-   Should we check average or maximum values?\n\
- -v, --variable=INTEGER\n\
-   Which variable set should we inspect? (1 or 2)\n\
- -w, --warning=INTEGER\n\
-   Threshold value for data to result in WARNING status\n\
- -c, --critical=INTEGER\n\
-   Threshold value for data to result in CRITICAL status\n"));
+	printf (" %s\n", "-F, --logfile=FILE");
+  printf ("   %s\n", _("The MRTG log file containing the data you want to monitor"));
+  printf ("-e, --expires=MINUTES");
+  printf ("   %s\n", _("Minutes before MRTG data is considered to be too old"));
+  printf (" %s\n", "-a, --aggregation=AVG|MAX");
+  printf ("   %s\n", _("Should we check average or maximum values?"));
+  printf (" %s\n", "-v, --variable=INTEGER");
+  printf ("   %s\n", _("Which variable set should we inspect? (1 or 2)"));
+  printf (" %s\n", "-w, --warning=INTEGER");
+  printf ("   %s\n", _("Threshold value for data to result in WARNING status"));
+  printf (" %s\n", "-c, --critical=INTEGER");
+  printf ("   %s\n", _("Threshold value for data to result in CRITICAL status"));
+	printf (" %s\n", "-l, --label=STRING");
+  printf ("   %s\n", _("Type label for data (Examples: Conns, \"Processor Load\", In, Out)"));
+  printf (" %s\n", "-u, --units=STRING");
+  printf ("   %s\n", _("Option units label for data (Example: Packets/Sec, Errors/Sec,"));
+  printf ("   %s\n", _("\"Bytes Per Second\", \"%% Utilization\")"));
 
-	printf (_("\
- -l, --label=STRING\n\
-   Type label for data (Examples: Conns, \"Processor Load\", In, Out)\n\
- -u, --units=STRING\n\
-   Option units label for data (Example: Packets/Sec, Errors/Sec, \n\
-   \"Bytes Per Second\", \"%% Utilization\")\n"));
+	printf ("%s\n", _("If the value exceeds the <vwl> threshold, a WARNING status is returned. If"));
+  printf ("%s\n", _("the value exceeds the <vcl> threshold, a CRITICAL status is returned.  If"));
+  printf ("%s\n", _("the data in the log file is older than <expire_minutes> old, a WARNING"));
+  printf ("%s\n", _("status is returned and a warning message is printed."));
 
-	printf (_("\
-If the value exceeds the <vwl> threshold, a WARNING status is returned.  If\n\
-the value exceeds the <vcl> threshold, a CRITICAL status is returned.  If\n\
-the data in the log file is older than <expire_minutes> old, a WARNING\n\
-status is returned and a warning message is printed.\n\n"));
+	printf ("%s\n", _("This plugin is useful for monitoring MRTG data that does not correspond to"));
+  printf ("%s\n", _("bandwidth usage.  (Use the check_mrtgtraf plugin for monitoring bandwidth)."));
+  printf ("%s\n", _("It can be used to monitor any kind of data that MRTG is monitoring - errors,"));
+  printf ("%s\n", _("packets/sec, etc.  I use MRTG in conjuction with the Novell NLM that allows"));
+  printf ("%s\n", _("me to track processor utilization, user connections, drive space, etc and"));
+  printf ("%s\n\n", _("this plugin works well for monitoring that kind of data as well."));
 
-	printf(_("This plugin is useful for monitoring MRTG data that does not correspond to\n\
-bandwidth usage.  (Use the check_mrtgtraf plugin for monitoring bandwidth).\n\
-It can be used to monitor any kind of data that MRTG is monitoring - errors,\n\
-packets/sec, etc.  I use MRTG in conjuction with the Novell NLM that allows\n\
-me to track processor utilization, user connections, drive space, etc and\n\
-this plugin works well for monitoring that kind of data as well.\n\n"));
-
-	printf (_("Notes:\n\
-- This plugin only monitors one of the two variables stored in the MRTG log\n\
-  file.  If you want to monitor both values you will have to define two\n\
-  commands with different values for the <variable> argument.  Of course,\n\
-  you can always hack the code to make this plugin work for you...\n\
-- MRTG stands for the Multi Router Traffic Grapher.  It can be downloaded from\n\
-  http://ee-staff.ethz.ch/~oetiker/webtools/mrtg/mrtg.html\n"));
+	printf ("%s\n", _("Notes:"));
+  printf (" %s\n", _("- This plugin only monitors one of the two variables stored in the MRTG log"));
+  printf (" %s\n", _("  file.  If you want to monitor both values you will have to define two"));
+  printf (" %s\n", _("  commands with different values for the <variable> argument.  Of course,"));
+  printf (" %s\n", _("you can always hack the code to make this plugin work for you..."));
+  printf (" %s\n", _("- MRTG stands for the Multi Router Traffic Grapher.  It can be downloaded from"));
+  printf (" %s\n", _("http://ee-staff.ethz.ch/~oetiker/webtools/mrtg/mrtg.html"));
 
 	printf (_(UT_SUPPORT));
 }
@@ -366,8 +380,7 @@ this plugin works well for monitoring that kind of data as well.\n\n"));
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -F log_file -a <AVG | MAX> -v variable -w warning -c critical\n\
-                  [-l label] [-u units] [-e expire_minutes] [-t timeout]\n\
-                  [-v]\n", progname);
+  printf (_("Usage:"));
+	printf ("%s -F log_file -a <AVG | MAX> -v variable -w warning -c critical\n",progname);
+  printf ("[-l label] [-u units] [-e expire_minutes] [-t timeout] [-v]\n");
 }
