@@ -1,26 +1,45 @@
 /******************************************************************************
+*
+* Nagios check_nagios plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 00:25:16 $
+*
+* Description:
+*
+* This file contains the check_nagios plugin
+*
+*  This plugin checks the status of the Nagios process on the local machine
+*  The plugin will check to make sure the Nagios status log is no older than
+*  the number of minutes specified by the expires option.
+*  It also checks the process table for a process matching the command argument.
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_nagios.c,v 1.29 2005/12/02 22:28:06 tonvoon Exp $
+ $Id: check_nagios.c,v 1.31 2006/10/19 00:25:16 opensides Exp $
  
 ******************************************************************************/
 
 const char *progname = "check_nagios";
-const char *revision = "$Revision: 1.29 $";
-const char *copyright = "1999-2004";
+const char *revision = "$Revision: 1.31 $";
+const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -262,27 +281,28 @@ print_help (void)
 
 	printf (_(COPYRIGHT), copyright, email);
 
-	printf (_("\
-This plugin checks the status of the Nagios process on the local\n\
-machine. The plugin will check to make sure the Nagios status log is no older\n\
-than the number of minutes specified by the expires option. It also\n\
-checks the process table for a process matching the command argument.\n\n"));
+	printf ("%s\n", _("This plugin checks the status of the Nagios process on the local machine"));
+  printf ("%s\n", _("The plugin will check to make sure the Nagios status log is no older than"));
+  printf ("%s\n", _("the number of minutes specified by the expires option."));
+  printf ("%s\n", _("It also checks the process table for a process matching the command argument."));
 
+  printf ("\n\n");
+  
 	print_usage ();
 
 	printf (_(UT_HELP_VRSN));
 
-	printf (_("\
- -F, --filename=FILE\n\
-   Name of the log file to check\n\
- -e, --expires=INTEGER\n\
-   Minutes aging after which logfile is considered stale\n\
- -C, --command=STRING\n\
-   Substring to search for in process arguments\n"));
-
-	printf (_("\
-Example:\n\
-   ./check_nagios -e 5 -F /usr/local/nagios/var/status.log -C /usr/local/nagios/bin/nagios\n"));
+	printf (" %s\n", "-F, --filename=FILE");
+  printf ("    %s\n", _("Name of the log file to check"));
+  printf (" %s\n", "-e, --expires=INTEGER");
+  printf ("    %s\n", _("Minutes aging after which logfile is considered stale"));
+  printf (" %s\n", "-C, --command=STRING");
+  printf ("    %s\n", _("Substring to search for in process arguments"));
+  printf (_(UT_VERBOSE));
+  printf ("\n");
+  printf ("%s\n", _("Examples:"));
+  printf (" %s\n", "check_nagios -e 5 -F /usr/local/nagios/var/status.log -C /usr/local/nagios/bin/nagios");
+  printf (_(UT_SUPPORT));
 }
 
 
@@ -290,6 +310,6 @@ Example:\n\
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -F <status log file> -e <expire_minutes> -C <process_string>\n", progname);
+  printf (_("Usage:"));
+	printf ("%s -F <status log file> -e <expire_minutes> -C <process_string>\n", progname);
 }
