@@ -1,38 +1,44 @@
 /******************************************************************************
- *
- * CHECK_NT.C
- *
- * Program: Windows NT plugin for Nagios
- * License: GPL
- * Copyright (c) 2000-2002 Yves Rubin (rubiyz@yahoo.com)
- *
- * Description:
- * 
- * This requires NSClient software to run on NT (http://nsclient.ready2run.nl/)
- *
- * License Information:
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- * $Id: check_nt.c,v 1.39 2005/01/19 23:39:45 harpermann Exp $
- *
- *****************************************************************************/
+*
+* Nagios check_nt plugin
+*
+* License: GPL
+* Copyright (c) 2000-2002 Yves Rubin (rubiyz@yahoo.com)
+* Copyright (c) 2003-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/24 21:48:22 $
+*
+* Description:
+*
+* This file contains the check_nt plugin
+*
+*  This plugin collects data from the NSClient service running on a
+*  Windows NT/2000/XP/2003 server.
+*  This requires NSClient software to run on NT (http://nsclient.ready2run.nl/)
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*
+* $Id: check_nt.c,v 1.45 2006/10/24 21:48:22 opensides Exp $
+*
+*****************************************************************************/
 
 const char *progname = "check_nt";
-const char *revision = "$Revision: 1.39 $";
-const char *copyright = "2003-2004";
+const char *revision = "$Revision: 1.45 $";
+const char *copyright = "2003-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -614,82 +620,91 @@ void print_help(void)
 	printf ("Copyright (c) 2000 Yves Rubin (rubiyz@yahoo.com)\n");
 	printf (COPYRIGHT, copyright, email);
 	
-	printf (_("This plugin collects data from the NSClient service running on a\n\
-Windows NT/2000/XP/2003 server.\n\n"));
+	printf ("%s\n", _("This plugin collects data from the NSClient service running on a"));
+  printf ("%s\n", _("Windows NT/2000/XP/2003 server."));
 
+  printf ("\n\n");
+  
 	print_usage();
 	
-  printf (_("\nOptions:\n\
--H, --hostname=HOST\n\
-  Name of the host to check\n\
--p, --port=INTEGER\n\
-  Optional port number (default: %d)\n\
--s <password>\n\
-  Password needed for the request\n\
--w, --warning=INTEGER\n\
-  Threshold which will result in a warning status\n\
--c, --critical=INTEGER\n\
-  Threshold which will result in a critical status\n\
--t, --timeout=INTEGER\n\
-  Seconds before connection attempt times out (default: %d)\n\
--h, --help\n\
-  Print this help screen\n\
--V, --version\n\
-  Print version information\n"), PORT, DEFAULT_SOCKET_TIMEOUT);
-	
-  printf (_("\
--v, --variable=STRING\n\
-  Variable to check.  Valid variables are:\n"));
-  printf (_("\
-   CLIENTVERSION = Get the NSClient version\n\
-     If -l <version> is specified, will return warning if versions differ.\n"));
-  printf (_("\
-   CPULOAD = Average CPU load on last x minutes.\n\
-     Request a -l parameter with the following syntax:\n\
-     -l <minutes range>,<warning threshold>,<critical threshold>.\n\
-     <minute range> should be less than 24*60.\n\
-     Thresholds are percentage and up to 10 requests can be done in one shot.\n\
-     ie: -l 60,90,95,120,90,95\n"));
-  printf (_("\
-   UPTIME = Get the uptime of the machine.\n\
-     No specific parameters. No warning or critical threshold\n"));
-  printf (_("\
-   USEDDISKSPACE = Size and percentage of disk use.\n\
-     Request a -l parameter containing the drive letter only.\n\
-     Warning and critical thresholds can be specified with -w and -c.\n"));
-  printf (_("\
-   MEMUSE = Memory use.\n\
-     Warning and critical thresholds can be specified with -w and -c.\n"));
-  printf (_("\
-   SERVICESTATE = Check the state of one or several services.\n\
-     Request a -l parameters with the following syntax:\n\
-     -l <service1>,<service2>,<service3>,...\n\
-     You can specify -d SHOWALL in case you want to see working services\n\
-		 in the returned string.\n"));
-  printf (_("\
-   PROCSTATE = Check if one or several process are running.\n\
-     Same syntax as SERVICESTATE.\n"));
-  printf (_("\
-   COUNTER = Check any performance counter of Windows NT/2000.\n\
-     Request a -l parameters with the following syntax:\n\
-		 -l \"\\\\<performance object>\\\\counter\",\"<description>\n\
-     The <description> parameter is optional and \n\
-     is given to a printf output command which requires a float parameter.\n\
-     If <description> does not include \"%%\", it is used as a label.\n\
-     Some examples:\n\
-       \"Paging file usage is %%.2f %%%%\"\n\
-       \"%%.f %%%% paging file used.\"\n"));
-  printf (_("Notes:\n\
- - The NSClient service should be running on the server to get any information\n\
-   (http://nsclient.ready2run.nl).\n\
- - Critical thresholds should be lower than warning thresholds\n"));
+  printf (_(UT_HELP_VRSN));
+
+    printf ("%s\n", _("Options:"));
+  printf (" %s\n", "-H, --hostname=HOST");
+  printf ("   %s\n", _("Name of the host to check"));
+  printf (" %s\n", "-p, --port=INTEGER");
+  printf ("   %s", _("Optional port number (default: "));
+  printf ("%d)\n", PORT);
+  printf (" %s\n", "-s <password>");
+  printf ("   %s\n", _("Password needed for the request"));
+  printf (" %s\n", "-w, --warning=INTEGER");
+  printf ("   %s\n", _("Threshold which will result in a warning status"));
+  printf (" %s\n", "-c, --critical=INTEGER");
+  printf ("   %s\n", _("Threshold which will result in a critical status"));
+  printf (" %s\n", "-t, --timeout=INTEGER");
+  printf ("   %s", _("Seconds before connection attempt times out (default: "));
+  printf ("%d)\n", DEFAULT_SOCKET_TIMEOUT);
+  printf (" %s\n", "-h, --help");
+  printf ("   %s\n", _("Print this help screen"));
+  printf (" %s\n", "-V, --version");
+  printf ("   %s\n", _("Print version information"));
+  printf (" %s\n", "-v, --variable=STRING");
+  printf ("   %s\n\n", _("Variable to check"));
+  printf ("%s\n", _("Valid variables are:"));
+  printf (" %s", "CLIENTVERSION =");
+  printf (" %s\n", _("Get the NSClient version"));
+  printf ("  %s\n", _("If -l <version> is specified, will return warning if versions differ."));
+  printf (" %s\n", "CPULOAD =");
+  printf ("  %s\n", _("Average CPU load on last x minutes."));
+  printf ("  %s\n", _("Request a -l parameter with the following syntax:"));
+  printf ("  %s\n", _("-l <minutes range>,<warning threshold>,<critical threshold>."));
+  printf ("  %s\n", _("<minute range> should be less than 24*60."));
+  printf ("  %s\n", _("Thresholds are percentage and up to 10 requests can be done in one shot."));
+  printf ("  %s\n", "ie: -l 60,90,95,120,90,95");
+  printf (" %s\n", "UPTIME =");
+  printf ("  %s\n", _("Get the uptime of the machine."));
+  printf ("  %s\n", _("No specific parameters. No warning or critical threshold"));
+  printf (" %s\n", "USEDDISKSPACE =");
+  printf ("  %s\n", _("Size and percentage of disk use."));
+  printf ("  %s\n", _("Request a -l parameter containing the drive letter only."));
+  printf ("  %s\n", _("Warning and critical thresholds can be specified with -w and -c."));
+  printf (" %s\n", "MEMUSE =");
+  printf ("  %s\n", _("Memory use."));
+  printf ("  %s\n", _("Warning and critical thresholds can be specified with -w and -c."));
+  printf (" %s\n,", "SERVICESTATE =");
+  printf ("  %s\n", _("Check the state of one or several services."));
+  printf ("  %s\n", _("Request a -l parameters with the following syntax:"));
+  printf ("  %s\n", _("-l <service1>,<service2>,<service3>,..."));
+  printf ("  %s\n", _("You can specify -d SHOWALL in case you want to see working services"));
+  printf ("  %s\n", _("in the returned string."));
+  printf (" %s\n", "PROCSTATE =");
+  printf ("  %s\n", _("Check if one or several process are running."));
+  printf ("  %s\n", _("Same syntax as SERVICESTATE."));
+  printf (" %s\n", "COUNTER =");
+  printf ("  %s\n", _("Check any performance counter of Windows NT/2000."));
+  printf ("  %s\n", _("Request a -l parameters with the following syntax:"));
+  printf ("  %s\n", _("-l \"\\\\<performance object>\\\\counter\",\"<description>"));
+  printf ("  %s\n", _("The <description> parameter is optional and is given to a printf "));
+  printf ("  %s\n", _("output command which requires a float parameter."));
+  printf ("  %s\n\n", _("If <description> does not include \"%%\", it is used as a label."));
+  printf ("  %s\n", _("Some examples:"));
+  printf ("  %s\n", "\"Paging file usage is %%.2f %%%%\"");
+  printf ("  %s\n\n", "\"%%.f %%%% paging file used.\"");
+  printf (_("Notes:"));
+  printf (" %s\n", _("- The NSClient service should be running on the server to get any information"));
+  printf (" %s\n", "(http://nsclient.ready2run.nl).");
+  printf (" %s\n", _("- Critical thresholds should be lower than warning thresholds"));
+  printf (" %s\n", _("- Default port 1248 is sometimes in use by other services. The error"));
+  printf (" %s\n", _("output when this happens contains \"Cannot map xxxxx to protocol number\"."));
+  printf (" %s\n", _("One fix for this is to change the port to something else on check_nt "));
+  printf (" %s\n", _("and on the client service it\'s connecting to."));
 }
 
 
 
 void print_usage(void)
 {
-	printf("\
-Usage: %s -H host -v variable [-p port] [-w warning] [-c critical]\n\
-                [-l params] [-d SHOWALL] [-t timeout]\n", progname);
+  printf (_("Usage:"));
+	printf ("%s -H host -v variable [-p port] [-w warning] [-c critical]",progname);
+  printf ("[-l params] [-d SHOWALL] [-t timeout]\n");
 }
