@@ -1,26 +1,43 @@
 /******************************************************************************
-
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_smtp.c,v 1.50 2005/11/02 08:47:26 seanius Exp $
- 
+*
+* Nagios check_smtp plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 23:53:28 $
+*
+* Description:
+*
+* This file contains the check_smtp plugin
+*
+*  This plugin will attempt to open an SMTP connection with the host.
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*
+*
+* $Id: check_smtp.c,v 1.54 2006/10/19 23:53:28 opensides Exp $
+* 
 ******************************************************************************/
 
 const char *progname = "check_smtp";
-const char *revision = "$Revision: 1.50 $";
-const char *copyright = "2000-2004";
+const char *revision = "$Revision: 1.54 $";
+const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -59,8 +76,7 @@ void print_help (void);
 void print_usage (void);
 int my_close(void);
 
-#ifdef HAVE_REGEX_H
-#include <regex.h>
+#include "regex.h"
 char regex_expect[MAX_INPUT_BUFFER] = "";
 regex_t preg;
 regmatch_t pmatch[10];
@@ -69,7 +85,6 @@ char errbuf[MAX_INPUT_BUFFER];
 int cflags = REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 int eflags = 0;
 int errcode, excode;
-#endif
 
 int server_port = SMTP_PORT;
 char *server_address = NULL;
@@ -270,6 +285,35 @@ main (int argc, char **argv)
 		  } else {
 			ssl_established = 1;
 		  }
+
+		/*
+		 * Resend the EHLO command.
+		 *
+		 * RFC 3207 (4.2) says: ``The client MUST discard any knowledge
+		 * obtained from the server, such as the list of SMTP service
+		 * extensions, which was not obtained from the TLS negotiation
+		 * itself.  The client SHOULD send an EHLO command as the first
+		 * command after a successful TLS negotiation.''  For this
+		 * reason, some MTAs will not allow an AUTH LOGIN command before
+		 * we resent EHLO via TLS.
+		 */
+		if (my_send(helocmd, strlen(helocmd)) <= 0) {
+			printf(_("SMTP UNKNOWN - Cannot send EHLO command via TLS.\n"));
+			my_close();
+			return STATE_UNKNOWN;
+		}
+		if (verbose)
+			printf(_("sent %s"), helocmd);
+		if ((n = my_recv(buffer, MAX_INPUT_BUFFER - 1)) <= 0) {
+			printf(_("SMTP UNKNOWN - Cannot read EHLO response via TLS.\n"));
+			my_close();
+			return STATE_UNKNOWN;
+		}
+		if (verbose) {
+			buffer[n] = '\0';
+			printf("%s", buffer);
+		}
+
 #  ifdef USE_OPENSSL
 		  if ( check_cert ) {
 		    result = np_net_ssl_check_cert(days_till_exp);
@@ -308,7 +352,6 @@ main (int argc, char **argv)
 				printf("%s", buffer);
 			strip (buffer);
 			if (n < nresponses) {
-#ifdef HAVE_REGEX_H
 				cflags |= REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 				errcode = regcomp (&preg, responses[n], cflags);
 				if (errcode != 0) {
@@ -329,12 +372,6 @@ main (int argc, char **argv)
 					printf (_("Execute Error: %s\n"), errbuf);
 					result = STATE_UNKNOWN;
 				}
-#else
-				if (strstr(buffer, responses[n])!=buffer) {
-					result = STATE_WARNING;
-					printf (_("SMTP %s - Invalid response '%s' to command '%s'\n"), state_text (result), buffer, commands[n]);
-				}
-#endif
 			}
 			n++;
 		}
@@ -666,6 +703,15 @@ validate_arguments (void)
 }
 
 
+int 
+my_close (void)
+{
+#ifdef HAVE_SSL
+  np_net_ssl_cleanup();
+#endif
+  return close(sd);
+}
+
 
 void
 print_help (void)
@@ -678,7 +724,9 @@ print_help (void)
 	printf ("Copyright (c) 1999-2001 Ethan Galstad <nagios@nagios.org>\n");
 	printf (COPYRIGHT, copyright, email);
 
-	printf(_("This plugin will attempt to open an SMTP connection with the host.\n\n"));
+	printf("%s\n", _("This plugin will attempt to open an SMTP connection with the host."));
+
+  printf ("\n\n");
 
 	print_usage ();
 
@@ -688,34 +736,29 @@ print_help (void)
 
 	printf (_(UT_IPv46));
 
-	printf (_("\
- -e, --expect=STRING\n\
-   String to expect in first line of server response (default: '%s')\n\
- -n, nocommand\n\
-   Suppress SMTP command\n\
- -C, --command=STRING\n\
-   SMTP command (may be used repeatedly)\n\
- -R, --command=STRING\n\
-   Expected response to command (may be used repeatedly)\n\
- -f, --from=STRING\n\
-   FROM-address to include in MAIL command, required by Exchange 2000\n"),
-	        SMTP_EXPECT);
+	printf (" %s\n", "-e, --expect=STRING");
+  printf (_("    String to expect in first line of server response (default: '%s')\n"), SMTP_EXPECT);
+  printf (" %s\n", "-n, nocommand");
+  printf ("    %s\n", _("Suppress SMTP command"));
+  printf (" %s\n", "-C, --command=STRING");
+  printf ("    %s\n", _("SMTP command (may be used repeatedly)"));
+  printf (" %s\n", "-R, --command=STRING");
+  printf ("    %s\n", _("Expected response to command (may be used repeatedly)"));
+  printf (" %s\n", "-f, --from=STRING");
+  printf ("    %s\n", _("FROM-address to include in MAIL command, required by Exchange 2000")),
 #ifdef HAVE_SSL
-        printf (_("\
- -D, --certificate=INTEGER\n\
-    Minimum number of days a certificate has to be valid.\n\
- -S, --starttls\n\
-    Use STARTTLS for the connection.\n"));
+  printf (" %s\n", "-D, --certificate=INTEGER");
+  printf ("    %s\n", _("Minimum number of days a certificate has to be valid."));
+  printf (" %s\n", "-S, --starttls");
+  printf ("    %s\n", _("Use STARTTLS for the connection."));
 #endif
 
-	printf("\
- -A, --authtype=STRING\n\
-   SMTP AUTH type to check (default none, only LOGIN supported)\n\
- -U, --authuser=STRING\n\
-   SMTP AUTH username\n\
- -P, --authpass=STRING\n\
-   SMTP AUTH password\n\
-			");
+	printf (" %s\n", "-A, --authtype=STRING");
+  printf ("    %s\n", _("SMTP AUTH type to check (default none, only LOGIN supported)"));
+  printf (" %s\n", "-U, --authuser=STRING");
+  printf ("    %s\n", _("SMTP AUTH username"));
+  printf (" %s\n", "-P, --authpass=STRING");
+  printf ("    %s\n", _("SMTP AUTH password"));
 
 	printf (_(UT_WARN_CRIT));
 
@@ -723,11 +766,11 @@ print_help (void)
 
 	printf (_(UT_VERBOSE));
 
-	printf(_("\n\
-Successul connects return STATE_OK, refusals and timeouts return\n\
-STATE_CRITICAL, other errors return STATE_UNKNOWN.  Successful\n\
-connects, but incorrect reponse messages from the host result in\n\
-STATE_WARNING return values.\n"));
+	printf("\n");
+	printf ("%s\n", _("Successul connects return STATE_OK, refusals and timeouts return"));
+  printf ("%s\n", _("STATE_CRITICAL, other errors return STATE_UNKNOWN.  Successful"));
+  printf ("%s\n", _("connects, but incorrect reponse messages from the host result in"));
+  printf ("%s\n", _("STATE_WARNING return values."));
 
 	printf (_(UT_SUPPORT));
 }
@@ -737,17 +780,9 @@ STATE_WARNING return values.\n"));
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -H host [-p port] [-e expect] [-C command] [-f from addr]\n\
-                  [-A authtype -U authuser -P authpass]\n\
-                  [-w warn] [-c crit] [-t timeout] [-S] [-D days] [-n] [-v] [-4|-6]\n", progname);
+  printf (_("Usage:"));
+	printf ("%s -H host [-p port] [-e expect] [-C command] [-f from addr]", progname);
+  printf ("[-A authtype -U authuser -P authpass] [-w warn] [-c crit] [-t timeout]\n");
+  printf ("[-S] [-D days] [-n] [-v] [-4|-6]\n");
 }
 
-int 
-my_close (void)
-{
-#ifdef HAVE_SSL
-	np_net_ssl_cleanup();
-#endif
-	return close(sd);
-}
