@@ -1,26 +1,42 @@
 /******************************************************************************
-
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_snmp.c,v 1.58 2005/10/31 20:03:19 seanius Exp $
- 
+*
+* Nagios check_snmp plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/20 07:53:31 $
+*
+* Description:
+*
+* This file contains the check_snmp plugin
+*
+*  Check status of remote machines and obtain sustem information via SNMP
+*
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*
+* $Id: check_snmp.c,v 1.67 2006/10/20 07:53:31 tonvoon Exp $
+* 
 ******************************************************************************/
 
 const char *progname = "check_snmp";
-const char *revision = "$Revision: 1.58 $";
-const char *copyright = "1999-2004";
+const char *revision = "$Revision: 1.67 $";
+const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -75,18 +91,16 @@ char *nextarg (char *str);
 void print_usage (void);
 void print_help (void);
 
-#ifdef HAVE_REGEX_H
-#include <regex.h>
+#include "regex.h"
 char regex_expect[MAX_INPUT_BUFFER] = "";
 regex_t preg;
 regmatch_t pmatch[10];
 char timestamp[10] = "";
-char errbuf[MAX_INPUT_BUFFER];
-char perfstr[MAX_INPUT_BUFFER];
+char errbuf[MAX_INPUT_BUFFER] = "";
+char perfstr[MAX_INPUT_BUFFER] = "";
 int cflags = REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 int eflags = 0;
 int errcode, excode;
-#endif
 
 char *server_address = NULL;
 char *community = NULL;
@@ -140,7 +154,7 @@ main (int argc, char **argv)
 	char *ptr = NULL;
 	char *p2 = NULL;
 	char *show = NULL;
-	char type[8];
+	char type[8] = "";
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
@@ -242,6 +256,10 @@ main (int argc, char **argv)
 		}
 
 		/* We strip out the datatype indicator for PHBs */
+
+		/* Clean up type array - Sol10 does not necessarily zero it out */
+		bzero(type, sizeof(type));
+
 		if (strstr (response, "Gauge: "))
 			show = strstr (response, "Gauge: ") + 7;
 		else if (strstr (response, "Gauge32: "))
@@ -291,7 +309,6 @@ main (int argc, char **argv)
 
 		/* Process this block for regex matching */
 		else if (eval_method[i] & CRIT_REGEX) {
-#ifdef HAVE_REGEX_H
 			excode = regexec (&preg, response, 10, pmatch, eflags);
 			if (excode == 0) {
 				iresult = STATE_OK;
@@ -304,10 +321,6 @@ main (int argc, char **argv)
 			else {
 				iresult = STATE_CRITICAL;
 			}
-#else
-			printf (_("Call for regex which was not a compiled option"));
-			exit (STATE_UNKNOWN);
-#endif
 		}
 
 		/* Process this block for existence-nonexistence checks */
@@ -338,9 +351,11 @@ main (int argc, char **argv)
 
 		i++;
 
-		char *str[MAX_INPUT_BUFFER];
-		asprintf(str, "=%s%s;;;; ", show, type ? type : "");
-		strcat(perfstr, *str);
+		strcat(perfstr, "=");
+		strcat(perfstr, show);
+		if (type)
+			strcat(perfstr, type);
+		strcat(perfstr, " ");
 
 	}	/* end while (ptr) */
 
@@ -542,11 +557,8 @@ process_arguments (int argc, char **argv)
 			ii++;
 			break;
 		case 'R':									/* regex */
-#ifdef HAVE_REGEX_H
 			cflags = REG_ICASE;
-#endif
 		case 'r':									/* regex */
-#ifdef HAVE_REGEX_H
 			cflags |= REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 			strncpy (regex_expect, optarg, sizeof (regex_expect) - 1);
 			regex_expect[sizeof (regex_expect) - 1] = 0;
@@ -558,10 +570,6 @@ process_arguments (int argc, char **argv)
 			}
 			eval_method[jj++] = CRIT_REGEX;
 			ii++;
-#else
-			printf (_("call for regex which was not a compiled option"));
-			exit (STATE_UNKNOWN);
-#endif
 			break;
 
 	/* Format */
@@ -898,8 +906,9 @@ print_help (void)
 
 	printf (COPYRIGHT, copyright, email);
 
-	printf (_("\
-Check status of remote machines and obtain sustem information via SNMP\n\n"));
+	printf ("%s\n", _("Check status of remote machines and obtain sustem information via SNMP"));
+
+  printf ("\n\n");
 
 	print_usage ();
 
@@ -908,95 +917,84 @@ Check status of remote machines and obtain sustem information via SNMP\n\n"));
 	printf (_(UT_HOST_PORT), 'p', DEFAULT_PORT);
 
 	/* SNMP and Authentication Protocol */
-	printf (_("\
- -n, --next\n\
-    Use SNMP GETNEXT instead of SNMP GET\n\
- -P, --protocol=[1|2c|3]\n\
-    SNMP protocol version\n\
- -L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]\n\
-    SNMPv3 securityLevel\n\
- -a, --authproto=[MD5|SHA]\n\
-    SNMPv3 auth proto\n"));
+	printf (" %s\n", "-n, --next");
+  printf ("    %s\n", _("Use SNMP GETNEXT instead of SNMP GET"));
+  printf (" %s\n", "-P, --protocol=[1|2c|3]");
+  printf ("    %s\n", _("SNMP protocol version"));
+  printf (" %s\n", "-L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]");
+  printf ("    %s\n", _("SNMPv3 securityLevel"));
+  printf (" %s\n", "-a, --authproto=[MD5|SHA]");
+  printf ("    %s\n", _("SNMPv3 auth proto"));
 
 	/* Authentication Tokens*/
-	printf (_("\
- -C, --community=STRING\n\
-    Optional community string for SNMP communication\n\
-    (default is \"%s\")\n\
- -U, --secname=USERNAME\n\
-    SNMPv3 username\n\
- -A, --authpassword=PASSWORD\n\
-    SNMPv3 authentication password\n\
- -X, --privpasswd=PASSWORD\n\
-    SNMPv3 crypt passwd (DES)\n"), DEFAULT_COMMUNITY);
+	printf (" %s\n", "-C, --community=STRING");
+  printf ("    %s\n", _("Optional community string for SNMP communication"));
+  printf (_("(default is \"%s\")"),DEFAULT_COMMUNITY);
+  printf (" %s\n", "-U, --secname=USERNAME");
+  printf ("    %s\n", _("SNMPv3 username"));
+  printf (" %s\n", "-A, --authpassword=PASSWORD");
+  printf ("    %s\n", _("SNMPv3 authentication password"));
+  printf (" %s\n", "-X, --privpasswd=PASSWORD");
+  printf ("    %s\n", _("SNMPv3 crypt passwd (DES)"));
 
 	/* OID Stuff */
-	printf (_("\
- -o, --oid=OID(s)\n\
-    Object identifier(s) or SNMP variables whose value you wish to query\n\
- -m, --miblist=STRING\n\
-    List of MIBS to be loaded (default = none if using numeric oids or 'ALL'\n\
-		for symbolic oids.)\n\
- -d, --delimiter=STRING\n\
-    Delimiter to use when parsing returned data. Default is \"%s\"\n\
-    Any data on the right hand side of the delimiter is considered\n\
-    to be the data that should be used in the evaluation.\n"), DEFAULT_DELIMITER);
+	printf (" %s\n", "-o, --oid=OID(s)");
+  printf ("    %s\n", _("Object identifier(s) or SNMP variables whose value you wish to query"));
+  printf (" %s\n", "-m, --miblist=STRING");
+  printf ("    %s\n", _("List of MIBS to be loaded (default = none if using numeric oids or 'ALL'"));
+  printf ("    %s\n", _("for symbolic oids.)"));
+  printf (" %s\n", "-d, --delimiter=STRING");
+  printf (_("    Delimiter to use when parsing returned data. Default is \"%s\""), DEFAULT_DELIMITER);
+  printf ("    %s\n", _("Any data on the right hand side of the delimiter is considered"));
+  printf ("    %s\n", _("to be the data that should be used in the evaluation."));
 
 	/* Tests Against Integers */
-	printf (_("\
- -w, --warning=INTEGER_RANGE(s)\n\
-    Range(s) which will not result in a WARNING status\n\
- -c, --critical=INTEGER_RANGE(s)\n\
-    Range(s) which will not result in a CRITICAL status\n"));
+	printf (" %s\n", "-w, --warning=INTEGER_RANGE(s)");
+  printf ("    %s\n", _("Range(s) which will not result in a WARNING status"));
+  printf (" %s\n", "-c, --critical=INTEGER_RANGE(s)");
+  printf ("    %s\n", _("Range(s) which will not result in a CRITICAL status"));
 
 	/* Tests Against Strings */
-	printf (_("\
- -s, --string=STRING\n\
-    Return OK state (for that OID) if STRING is an exact match\n\
- -r, --ereg=REGEX\n\
-    Return OK state (for that OID) if extended regular expression REGEX matches\n\
- -R, --eregi=REGEX\n\
-    Return OK state (for that OID) if case-insensitive extended REGEX matches\n\
- -l, --label=STRING\n\
-    Prefix label for output from plugin (default -s 'SNMP')\n"));
+	printf (" %s\n", "-s, --string=STRING");
+  printf ("    %s\n", _("Return OK state (for that OID) if STRING is an exact match"));
+  printf (" %s\n", "-r, --ereg=REGEX");
+  printf ("    %s\n", _("Return OK state (for that OID) if extended regular expression REGEX matches"));
+  printf (" %s\n", "-R, --eregi=REGEX");
+  printf ("    %s\n", _("Return OK state (for that OID) if case-insensitive extended REGEX matches"));
+  printf (" %s\n", "-l, --label=STRING");
+  printf ("    %s\n", _("Prefix label for output from plugin (default -s 'SNMP')"));
 
 	/* Output Formatting */
-	printf (_("\
- -u, --units=STRING\n\
-    Units label(s) for output data (e.g., 'sec.').\n\
- -D, --output-delimiter=STRING\n\
-    Separates output on multiple OID requests\n"));
+	printf (" %s\n", "-u, --units=STRING");
+  printf ("    %s\n", _("Units label(s) for output data (e.g., 'sec.')."));
+  printf (" %s\n", "-D, --output-delimiter=STRING");
+  printf ("    %s\n", _("Separates output on multiple OID requests"));
 
 	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
 
 	printf (_(UT_VERBOSE));
 
-	printf (_("\n\
-- This plugin uses the 'snmpget' command included with the NET-SNMP package.\n\
-  If you don't have the package installed, you will need to download it from\n\
-  http://net-snmp.sourceforge.net before you can use this plugin.\n"));
+	printf ("%s\n", _("This plugin uses the 'snmpget' command included with the NET-SNMP package."));
+  printf ("%s\n", _("if you don't have the package installed, you will need to download it from"));
+  printf ("%s\n", _("http://net-snmp.sourceforge.net before you can use this plugin."));
 
-	printf (_("\
-- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with\n\
-  internal spaces must be quoted) [max 8 OIDs]\n"));
+	printf ("%s\n", _("- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with"));
+  printf ("%s\n", _(" internal spaces must be quoted) [max 8 OIDs]"));
 
-	printf (_("\
-- Ranges are inclusive and are indicated with colons. When specified as\n\
-  'min:max' a STATE_OK will be returned if the result is within the indicated\n\
-  range or is equal to the upper or lower bound. A non-OK state will be\n\
-  returned if the result is outside the specified range.\n"));
+	printf ("%s\n", _("- Ranges are inclusive and are indicated with colons. When specified as"));
+  printf ("%s\n", _(" 'min:max' a STATE_OK will be returned if the result is within the indicated"));
+  printf ("%s\n", _(" range or is equal to the upper or lower bound. A non-OK state will be"));
+  printf ("%s\n", _(" returned if the result is outside the specified range."));
 
-	printf (_("\
-- If specified in the order 'max:min' a non-OK state will be returned if the\n\
-  result is within the (inclusive) range.\n"));
+	printf ("%s\n", _("- If specified in the order 'max:min' a non-OK state will be returned if the"));
+  printf ("%s\n", _(" result is within the (inclusive) range."));
 
-	printf (_("\
-- Upper or lower bounds may be omitted to skip checking the respective limit.\n\
-- Bare integers are interpreted as upper limits.\n\
-- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'\n\
-- Note that only one string and one regex may be checked at present\n\
-- All evaluation methods other than PR, STR, and SUBSTR expect that the value\n\
-  returned from the SNMP query is an unsigned integer.\n"));
+	printf ("%s\n", _("- Upper or lower bounds may be omitted to skip checking the respective limit."));
+  printf ("%s\n", _("- Bare integers are interpreted as upper limits."));
+  printf ("%s\n", _("- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'"));
+  printf ("%s\n", _("- Note that only one string and one regex may be checked at present"));
+  printf ("%s\n", _("- All evaluation methods other than PR, STR, and SUBSTR expect that the value"));
+  printf ("%s\n", _(" returned from the SNMP query is an unsigned integer."));
 
 	printf (_(UT_SUPPORT));
 }
@@ -1006,12 +1004,10 @@ Check status of remote machines and obtain sustem information via SNMP\n\n"));
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -H <ip_address> -o <OID> [-w warn_range] [-c crit_range] \n\
-                  [-C community] [-s string] [-r regex] [-R regexi]\n\
-                  [-t timeout] [-e retries]\n\
-                  [-l label] [-u units] [-p port-number] [-d delimiter]\n\
-                  [-D output-delimiter] [-m miblist] [-P snmp version]\n\
-                  [-L seclevel] [-U secname] [-a authproto] [-A authpasswd]\n\
-                  [-X privpasswd]\n", progname);
+  printf (_("Usage:"));
+	printf ("%s -H <ip_address> -o <OID> [-w warn_range] [-c crit_range]\n",progname);
+  printf ("[-C community] [-s string] [-r regex] [-R regexi] [-t timeout] [-e retries]\n");
+  printf ("[-l label] [-u units] [-p port-number] [-d delimiter] [-D output-delimiter]\n");
+  printf ("[-m miblist] [-P snmp version] [-L seclevel] [-U secname] [-a authproto]\n");
+  printf ("[-A authpasswd] [-X privpasswd]\n");
 }
