@@ -1,66 +1,56 @@
 /*****************************************************************************
-
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_tcp.c,v 1.66 2005/06/05 17:43:58 seanius Exp $
- 
+*
+* Nagios check_tcp plugin
+*
+* License: GPL
+* Copyright (c) 1999-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 23:53:28 $
+*
+* Description:
+*
+* This file contains the check_tcp plugin
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*
+* $Id: check_tcp.c,v 1.80 2006/10/19 23:53:28 opensides Exp $
+* 
 *****************************************************************************/
 
 /* progname "check_tcp" changes depending on symlink called */
 char *progname;
-const char *revision = "$Revision: 1.66 $";
-const char *copyright = "1999-2004";
+const char *revision = "$Revision: 1.80 $";
+const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
 #include "netutils.h"
 #include "utils.h"
 
-#ifdef HAVE_SSL_H
-#  include <rsa.h>
-#  include <crypto.h>
-#  include <x509.h>
-#  include <pem.h>
-#  include <ssl.h>
-#  include <err.h>
-#else
-#  ifdef HAVE_OPENSSL_SSL_H
-#    include <openssl/rsa.h>
-#    include <openssl/crypto.h>
-#    include <openssl/x509.h>
-#    include <openssl/pem.h>
-#    include <openssl/ssl.h>
-#    include <openssl/err.h>
-#  endif
-#endif
-
 #ifdef HAVE_SSL
 static int check_cert = FALSE;
 static int days_till_exp;
-static char *randbuff = "";
-static SSL_CTX *ctx;
-static SSL *ssl;
-static X509 *server_cert;
-static int connect_SSL (void);
-static int check_certificate (X509 **);
-# define my_recv(buf, len) ((flags & FLAG_SSL) ? SSL_read(ssl, buf, len) : read(sd, buf, len))
+# define my_recv(buf, len) ((flags & FLAG_SSL) ? np_net_ssl_read(buf, len) : read(sd, buf, len))
+# define my_send(buf, len) ((flags & FLAG_SSL) ? np_net_ssl_write(buf, len) : send(sd, buf, len, 0))
 #else
 # define my_recv(buf, len) read(sd, buf, len)
+# define my_send(buf, len) send(sd, buf, len, 0)
 #endif
 
-
 /* int my_recv(char *, size_t); */
 static int process_arguments (int, char **);
 void print_help (void);
@@ -73,7 +63,6 @@ static char *QUIT = NULL;
 static int PROTOCOL = IPPROTO_TCP; /* most common is default */
 static int PORT = 0;
 
-static char timestamp[17] = "";
 static int server_port = 0;
 static char *server_address = NULL;
 static char *server_send = NULL;
@@ -199,6 +188,12 @@ main (int argc, char **argv)
 		QUIT = "QUIT\r\n";
 		PORT = 119;
 	}
+	else if (!strncmp(SERVICE, "CLAMD", 5)) {
+		SEND = "PING";
+		EXPECT = "PONG";
+		QUIT = NULL;
+		PORT = 3310;
+	}
 	/* fallthrough check, so it's supposed to use reverse matching */
 	else if (strcmp (SERVICE, "TCP"))
 		usage (_("CRITICAL - Generic check_tcp called with unknown service\n"));
@@ -214,54 +209,46 @@ main (int argc, char **argv)
 
 	if(flags & FLAG_VERBOSE) {
 		printf("Using service %s\n", SERVICE);
-		printf("Port: %d\n", PORT);
-		printf("flags: 0x%x\n", flags);
+		printf("Port: %d\n", server_port);
+		printf("flags: 0x%x\n", (int)flags);
 	}
 
 	if(EXPECT && !server_expect_count)
 		server_expect_count++;
 
+	if(PROTOCOL==IPPROTO_UDP && !(server_expect_count && server_send)){
+		usage(_("With UDP checks, a send/expect string must be specified."));
+	}
+
 	/* set up the timer */
 	signal (SIGALRM, socket_timeout_alarm_handler);
 	alarm (socket_timeout);
 
 	/* try to connect to the host at the given port number */
 	gettimeofday (&tv, NULL);
-#ifdef HAVE_SSL
-	if (flags & FLAG_SSL && check_cert == TRUE) {
-		if (connect_SSL () != OK)
-			die (STATE_CRITICAL,_("CRITICAL - Could not make SSL connection\n"));
-		if ((server_cert = SSL_get_peer_certificate (ssl)) != NULL) {
-			result = check_certificate (&server_cert);
-			X509_free(server_cert);
-		}
-		else {
-			printf(_("CRITICAL - Cannot retrieve server certificate.\n"));
-			result = STATE_CRITICAL;
-		}
 
-		SSL_shutdown (ssl);
-		SSL_free (ssl);
-		SSL_CTX_free (ctx);
-		close (sd);
+	result = np_net_connect (server_address, server_port, &sd, PROTOCOL);
+	if (result == STATE_CRITICAL) return STATE_CRITICAL;
+
+#ifdef HAVE_SSL
+	if (flags & FLAG_SSL){
+		result = np_net_ssl_init(sd);
+		if (result == STATE_OK && check_cert == TRUE) {
+			result = np_net_ssl_check_cert(days_till_exp);
+			if(result != STATE_OK) {
+				printf(_("CRITICAL - Cannot retrieve server certificate.\n"));
+			}
+		}
+	}
+	if(result != STATE_OK){
+		np_net_ssl_cleanup();
+		if(sd) close(sd);
 		return result;
 	}
-	else if (flags & FLAG_SSL)
-		result = connect_SSL ();
-	else
-#endif
-		result = np_net_connect (server_address, server_port, &sd, PROTOCOL);
-
-	if (result == STATE_CRITICAL)
-		return STATE_CRITICAL;
+#endif /* HAVE_SSL */
 
 	if (server_send != NULL) {		/* Something to send? */
-#ifdef HAVE_SSL
-		if (flags & FLAG_SSL)
-			SSL_write(ssl, server_send, (int)strlen(server_send));
-		else
-#endif
-			send (sd, server_send, strlen(server_send), 0);
+		my_send(server_send, strlen(server_send));
 	}
 
 	if (delay > 0) {
@@ -270,7 +257,13 @@ main (int argc, char **argv)
 	}
 
 	if(flags & FLAG_VERBOSE) {
-		printf("server_expect_count: %d\n", server_expect_count);
+		if (server_send) {
+			printf("Send string: %s\n", server_send);
+		}
+		if (server_quit) {
+			printf("Quit string: %s\n", server_quit);
+		}
+		printf("server_expect_count: %d\n", (int)server_expect_count);
 		for(i = 0; i < server_expect_count; i++)
 			printf("\t%d: %s\n", i, server_expect[i]);
 	}
@@ -302,7 +295,7 @@ main (int argc, char **argv)
 		/* print raw output if we're debugging */
 		if(flags & FLAG_VERBOSE)
 			printf("received %d bytes from host\n#-raw-recv-------#\n%s\n#-raw-recv-------#\n",
-			       len + 1, status);
+			       (int)len + 1, status);
 		while(isspace(status[len])) status[len--] = '\0';
 
 		for (i = 0; i < server_expect_count; i++) {
@@ -324,21 +317,12 @@ main (int argc, char **argv)
 	}
 
 	if (server_quit != NULL) {
-#ifdef HAVE_SSL
-		if (flags & FLAG_SSL) {
-			SSL_write (ssl, server_quit, (int)strlen(server_quit));
-			SSL_shutdown (ssl);
- 			SSL_free (ssl);
- 			SSL_CTX_free (ctx);
-		}
-		else
-#endif
-			send (sd, server_quit, strlen (server_quit), 0);
+		my_send(server_quit, strlen(server_quit));
 	}
-
-	/* close the connection */
-	if (sd)
-		close (sd);
+#ifdef HAVE_SSL
+	np_net_ssl_cleanup();
+#endif 
+	if (sd) close (sd);
 
 	microsec = deltime (tv);
 	elapsed_time = (double)microsec / 1.0e6;
@@ -350,7 +334,7 @@ main (int argc, char **argv)
 
 	/* did we get the response we hoped? */
 	if(match == -2 && result != STATE_CRITICAL)
-		result = STATE_WARNING;
+		result = expect_mismatch_state;
 
 	/* reset the alarm */
 	alarm (0);
@@ -361,10 +345,14 @@ main (int argc, char **argv)
 	printf(_("%s %s - "), SERVICE, state_text(result));
 
 	if(match == -2 && len && !(flags & FLAG_HIDE_OUTPUT))
-		printf("Unexpected response from host: %s", status);
-	else
-		printf("%.3f second response time on port %d",
-		       elapsed_time, server_port);
+		printf("Unexpected response from host/socket: %s", status);
+	else {
+		printf("%.3f second response time on ", elapsed_time);
+		if(server_address[0] != '/')
+			printf("port %d", server_port);
+		else
+			printf("socket %s", server_address);
+	}
 
 	if (match != -2 && !(flags & FLAG_HIDE_OUTPUT) && len)
 		printf (" [%s]", status);
@@ -393,17 +381,19 @@ static int
 process_arguments (int argc, char **argv)
 {
 	int c;
+	int escape = 0;
 
 	int option = 0;
 	static struct option longopts[] = {
 		{"hostname", required_argument, 0, 'H'},
-		{"critical-time", required_argument, 0, 'c'},
-		{"warning-time", required_argument, 0, 'w'},
+		{"critical", required_argument, 0, 'c'},
+		{"warning", required_argument, 0, 'w'},
 		{"critical-codes", required_argument, 0, 'C'},
 		{"warning-codes", required_argument, 0, 'W'},
 		{"timeout", required_argument, 0, 't'},
 		{"protocol", required_argument, 0, 'P'},
 		{"port", required_argument, 0, 'p'},
+		{"escape", required_argument, 0, 'E'},
 		{"send", required_argument, 0, 's'},
 		{"expect", required_argument, 0, 'e'},
 		{"maxbytes", required_argument, 0, 'm'},
@@ -445,7 +435,7 @@ process_arguments (int argc, char **argv)
 	}
 
 	while (1) {
-		c = getopt_long (argc, argv, "+hVv46H:s:e:q:m:c:w:t:p:C:W:d:Sr:jD:M:",
+		c = getopt_long (argc, argv, "+hVv46EH:s:e:q:m:c:w:t:p:C:W:d:Sr:jD:M:",
 		                 longopts, &option);
 
 		if (c == -1 || c == EOF || c == 1)
@@ -474,25 +464,17 @@ process_arguments (int argc, char **argv)
 #endif
 			break;
 		case 'H':                 /* hostname */
-			if (is_host (optarg) == FALSE)
-				usage2 (_("Invalid hostname/address"), optarg);
 			server_address = optarg;
 			break;
 		case 'c':                 /* critical */
-			if (!is_intnonneg (optarg))
-				usage4 (_("Critical threshold must be a positive integer"));
-			else
-				critical_time = strtod (optarg, NULL);
+			critical_time = strtod (optarg, NULL);
 			flags |= FLAG_TIME_CRIT;
 			break;
 		case 'j':		  /* hide output */
 			flags |= FLAG_HIDE_OUTPUT;
 			break;
 		case 'w':                 /* warning */
-			if (!is_intnonneg (optarg))
-				usage4 (_("Warning threshold must be a positive integer"));
-			else
-				warning_time = strtod (optarg, NULL);
+			warning_time = strtod (optarg, NULL);
 			flags |= FLAG_TIME_WARN;
 			break;
 		case 'C':
@@ -515,8 +497,14 @@ process_arguments (int argc, char **argv)
 			else
 				server_port = atoi (optarg);
 			break;
+		case 'E':
+			escape = 1;
+			break;
 		case 's':
-			server_send = optarg;
+			if (escape)
+				server_send = np_escaped_string(optarg);
+			else
+				asprintf(&server_send, "%s", optarg);
 			break;
 		case 'e': /* expect string (may be repeated) */
 			EXPECT = NULL;
@@ -533,7 +521,10 @@ process_arguments (int argc, char **argv)
 			else
 				maxbytes = strtol (optarg, NULL, 0);
 		case 'q':
-			asprintf(&server_quit, "%s\r\n", optarg);
+			if (escape)
+				server_quit = np_escaped_string(optarg);
+			else
+				asprintf(&server_quit, "%s\r\n", optarg);
 			break;
 		case 'r':
 			if (!strncmp(optarg,"ok",2))
@@ -563,12 +554,14 @@ process_arguments (int argc, char **argv)
 			break;
 		case 'D': /* Check SSL cert validity - days 'til certificate expiration */
 #ifdef HAVE_SSL
+#  ifdef USE_OPENSSL /* XXX */
 			if (!is_intnonneg (optarg))
 				usage2 (_("Invalid certificate expiration period"), optarg);
 			days_till_exp = atoi (optarg);
 			check_cert = TRUE;
 			flags |= FLAG_SSL;
 			break;
+#  endif /* USE_OPENSSL */
 #endif
 			/* fallthrough if we don't have ssl */
 		case 'S':
@@ -583,141 +576,13 @@ process_arguments (int argc, char **argv)
 
 	if (server_address == NULL)
 		usage4 (_("You must provide a server address"));
+	else if (server_address[0] != '/' && is_host (server_address) == FALSE)
+		die (STATE_CRITICAL, "%s: %s - %s\n", progname, _("Invalid hostname, address or socket"), server_address);
 
 	return TRUE;
 }
 
 
-/* SSL-specific functions */
-#ifdef HAVE_SSL
-static int
-connect_SSL (void)
-{
-  SSL_METHOD *meth;
-
-  /* Initialize SSL context */
-  SSLeay_add_ssl_algorithms ();
-  meth = SSLv23_client_method ();
-  SSL_load_error_strings ();
-  OpenSSL_add_all_algorithms();
-  if ((ctx = SSL_CTX_new (meth)) == NULL)
-    {
-      printf (_("CRITICAL - Cannot create SSL context.\n"));
-      return STATE_CRITICAL;
-    }
-
-  /* Initialize alarm signal handling */
-  signal (SIGALRM, socket_timeout_alarm_handler);
-
-  /* Set socket timeout */
-  alarm (socket_timeout);
-
-  /* Save start time */
-  time (&start_time);
-
-  /* Make TCP connection */
-  if (my_tcp_connect (server_address, server_port, &sd) == STATE_OK && was_refused == FALSE)
-    {
-    /* Do the SSL handshake */
-      if ((ssl = SSL_new (ctx)) != NULL)
-      {
-        SSL_set_fd (ssl, sd);
-        if (SSL_connect(ssl) == 1)
-          return OK;
-        /* ERR_print_errors_fp (stderr); */
-	printf (_("CRITICAL - Cannot make  SSL connection "));
-        ERR_print_errors_fp (stdout);
-	/* printf("\n"); */
-      }
-      else
-      {
-        printf (_("CRITICAL - Cannot initiate SSL handshake.\n"));
-      }
-      SSL_free (ssl);
-    }
-
-  SSL_CTX_free (ctx);
-  close (sd);
-
-  return STATE_CRITICAL;
-}
-
-static int
-check_certificate (X509 ** certificate)
-{
-  ASN1_STRING *tm;
-  int offset;
-  struct tm stamp;
-  int days_left;
-
-
-  /* Retrieve timestamp of certificate */
-  tm = X509_get_notAfter (*certificate);
-
-  /* Generate tm structure to process timestamp */
-  if (tm->type == V_ASN1_UTCTIME) {
-    if (tm->length < 10) {
-      printf (_("CRITICAL - Wrong time format in certificate.\n"));
-      return STATE_CRITICAL;
-    }
-    else {
-      stamp.tm_year = (tm->data[0] - '0') * 10 + (tm->data[1] - '0');
-      if (stamp.tm_year < 50)
-	stamp.tm_year += 100;
-      offset = 0;
-    }
-  }
-  else {
-    if (tm->length < 12) {
-      printf (_("CRITICAL - Wrong time format in certificate.\n"));
-      return STATE_CRITICAL;
-    }
-    else {
-                        stamp.tm_year =
-			  (tm->data[0] - '0') * 1000 + (tm->data[1] - '0') * 100 +
-			  (tm->data[2] - '0') * 10 + (tm->data[3] - '0');
-                        stamp.tm_year -= 1900;
-                        offset = 2;
-    }
-  }
-        stamp.tm_mon =
-	  (tm->data[2 + offset] - '0') * 10 + (tm->data[3 + offset] - '0') - 1;
-        stamp.tm_mday =
-	  (tm->data[4 + offset] - '0') * 10 + (tm->data[5 + offset] - '0');
-        stamp.tm_hour =
-	  (tm->data[6 + offset] - '0') * 10 + (tm->data[7 + offset] - '0');
-        stamp.tm_min =
-	  (tm->data[8 + offset] - '0') * 10 + (tm->data[9 + offset] - '0');
-        stamp.tm_sec = 0;
-        stamp.tm_isdst = -1;
-
-        days_left = (mktime (&stamp) - time (NULL)) / 86400;
-        snprintf
-	  (timestamp, 16, "%02d/%02d/%04d %02d:%02d",
-	   stamp.tm_mon + 1,
-	   stamp.tm_mday, stamp.tm_year + 1900, stamp.tm_hour, stamp.tm_min);
-
-        if (days_left > 0 && days_left <= days_till_exp) {
-	  printf (_("Certificate expires in %d day(s) (%s).\n"), days_left, timestamp);
-	  return STATE_WARNING;
-        }
-        if (days_left < 0) {
-	  printf (_("Certificate expired on %s.\n"), timestamp);
-	  return STATE_CRITICAL;
-        }
-
-        if (days_left == 0) {
-	  printf (_("Certificate expires today (%s).\n"), timestamp);
-	  return STATE_WARNING;
-        }
-
-        printf (_("Certificate will expire on %s.\n"), timestamp);
-
-        return STATE_OK;
-}
-#endif /* HAVE_SSL */
-
-
 void
 print_help (void)
 {
@@ -726,7 +591,7 @@ print_help (void)
 	printf ("Copyright (c) 1999 Ethan Galstad <nagios@nagios.org>\n");
 	printf (COPYRIGHT, copyright, email);
 
-	printf (_("This plugin tests %s connections with the specified host.\n\n"),
+	printf (_("This plugin tests %s connections with the specified host (or unix socket).\n\n"),
 	        SERVICE);
 
 	print_usage ();
@@ -737,32 +602,31 @@ print_help (void)
 
 	printf (_(UT_IPv46));
 
-	printf (_("\
- -s, --send=STRING\n\
-    String to send to the server\n\
- -e, --expect=STRING\n\
-    String to expect in server response\n\
- -q, --quit=STRING\n\
-    String to send server to initiate a clean close of the connection\n"));
-
-	printf (_("\
- -r, --refuse=ok|warn|crit\n\
-    Accept tcp refusals with states ok, warn, crit (default: crit)\n\
- -M, --mismatch=ok|warn|crit\n\
-    Accept expected string mismatches with states ok, warn, crit (default: warn)\n\
- -j, --jail\n\
-    Hide output from TCP socket\n\
- -m, --maxbytes=INTEGER\n\
-    Close connection once more than this number of bytes are received\n\
- -d, --delay=INTEGER\n\
-    Seconds to wait between sending string and polling for response\n"));
+	printf (" %s\n", "-E, --escape");
+  printf ("    %s\n", _("Can use \\n, \\r, \\t or \\ in send or quit string."));
+  printf ("    %s\n", _("Default: nothing added to send, \\r\\n added to end of quit"));
+  printf (" %s\n", "-s, --send=STRING");
+  printf ("    %s\n", _("String to send to the server"));
+  printf (" %s\n", "-e, --expect=STRING");
+  printf ("    %s\n", _("String to expect in server response"));
+  printf (" %s\n", "-q, --quit=STRING");
+  printf ("    %s\n", _("String to send server to initiate a clean close of the connection"));
+	printf (" %s\n", "-r, --refuse=ok|warn|crit");
+  printf ("    %s\n", _("Accept tcp refusals with states ok, warn, crit (default: crit)"));
+  printf (" %s\n", "-M, --mismatch=ok|warn|crit");
+  printf ("    %s\n", _("Accept expected string mismatches with states ok, warn, crit (default: warn)"));
+  printf (" %s\n", "-j, --jail");
+  printf ("    %s\n", _("Hide output from TCP socket"));
+  printf (" %s\n", "-m, --maxbytes=INTEGER");
+  printf ("    %s\n", _("Close connection once more than this number of bytes are received"));
+  printf (" %s\n", "-d, --delay=INTEGER");
+  printf ("    %s\n", _("Seconds to wait between sending string and polling for response"));
 
 #ifdef HAVE_SSL
-	printf (_("\
- -D, --certificate=INTEGER\n\
-    Minimum number of days a certificate has to be valid.\n\
- -S, --ssl\n\
-    Use SSL for the connection.\n"));
+	printf (" %s\n", "-D, --certificate=INTEGER");
+  printf ("    %s\n", _("Minimum number of days a certificate has to be valid."));
+  printf (" %s\n", "-S, --ssl");
+  printf ("    %s\n", _("Use SSL for the connection."));
 #endif
 
 	printf (_(UT_WARN_CRIT));
@@ -778,11 +642,10 @@ print_help (void)
 void
 print_usage (void)
 {
-	printf ("\
-Usage: %s -H host -p port [-w <warning time>] [-c <critical time>]\n\
-                  [-s <send string>] [-e <expect string>] [-q <quit string>]\n\
-                  [-m <maximum bytes>] [-d <delay>] [-t <timeout seconds>]\n\
-                  [-r <refuse state>] [-M <mismatch state>] [-v] [-4|-6] [-j]\n\
-                  [-D <days to cert expiry>] [-S <use SSL>]\n", progname);
+	printf (_("Usage:"));
+  printf ("%s -H host -p port [-w <warning time>] [-c <critical time>] [-s <send string>]\n",progname);
+  printf ("[-e <expect string>] [-q <quit string>][-m <maximum bytes>] [-d <delay>]\n");
+  printf ("[-t <timeout seconds>] [-r <refuse state>] [-M <mismatch state>] [-v] [-4|-6] [-j]\n");
+  printf ("[-D <days to cert expiry>] [-S <use SSL>] [-E]\n");
 }
 
