@@ -28,7 +28,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: common.h,v 1.18 2005/12/07 15:10:27 tonvoon Exp $
+ * $Id: common.h,v 1.24 2006/07/29 01:43:34 tonvoon Exp $
  *
  *****************************************************************************/
 
@@ -45,6 +45,20 @@
 #include <stdlib.h>
 #include <errno.h>
 
+/* This block provides uintmax_t - should be reported to coreutils that this should be added to fsuage.h */
+#if HAVE_INTTYPES_H
+# include <inttypes.h>
+#endif
+#if HAVE_STDINT_H
+# include <stdint.h>
+#endif
+#include <unistd.h>
+#ifndef UINTMAX_MAX
+# define UINTMAX_MAX ((uintmax_t) -1)
+#endif
+
+#include <limits.h>	/* This is assumed true, because coreutils assume it too */
+
 #ifdef HAVE_MATH_H
 #include <math.h>
 #endif
@@ -83,10 +97,7 @@
 #include <signal.h>
 #endif
 
-/* TODO: define can be removed when all ifdef in each plugin has been removed */
-#define HAVE_GETOPT_H
 #include <getopt.h>
-
 #include <ctype.h>
 
 #ifdef HAVE_LWRES_NETDB_H
@@ -103,6 +114,11 @@
 #include <locale.h>
 #endif
 
+/* Fixes "Cannot use swapctl in the large files compilation environment" error on Solaris */
+#ifdef _FILE_OFFSET_BITS
+#undef _FILE_OFFSET_BITS
+#endif
+
 #ifdef HAVE_DECL_SWAPCTL
 # ifdef HAVE_SYS_SWAP_H
 #  include <sys/swap.h>
@@ -119,6 +135,10 @@
 # define SWAP_CONVERSION 1
 #endif
 
+#ifdef HAVE_SYS_POLL_H
+# include "sys/poll.h"
+#endif
+
 /*
  *
  * Missing Functions
@@ -217,6 +237,12 @@ enum {
  */
 #include "gettext.h"
 #define _(String) gettext (String)
+#if ! ENABLE_NLS
+# undef textdomain
+# define textdomain(Domainname) /* empty */
+# undef bindtextdomain
+# define bindtextdomain(Domainname, Dirname) /* empty */
+#endif
 
 /* For non-GNU compilers to ignore __attribute__ */
 #ifndef __GNUC__
