@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999 Ethan Galstad (nagios@nagios.org)
 *
-* Last Modified: $Date: 2005/05/25 00:30:19 $
+* Last Modified: $Date: 2005/10/31 20:03:19 $
 *
 * Description:
 *
@@ -28,14 +28,27 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: netutils.h,v 1.12 2005/05/25 00:30:19 seanius Exp $
+* $Id: netutils.h,v 1.16 2005/10/31 20:03:19 seanius Exp $
 *
 ******************************************************************************/
 
+#ifndef _NETUTILS_H_
+#define _NETUTILS_H_
+
 #include "config.h"
+#include "common.h"
+#include "utils.h"
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
+#ifdef HAVE_SYS_UN_H
+# include <sys/un.h>
+# ifndef UNIX_PATH_MAX
+   /* linux uses this, on sun it's hard-coded at 108 without a define */
+#  define UNIX_PATH_MAX 108
+# endif /* UNIX_PATH_MAX */
+#endif /* HAVE_SYS_UN_H */
+
 RETSIGTYPE socket_timeout_alarm_handler (int) __attribute__((noreturn));
 
 /* process_request and wrapper macros */
@@ -65,6 +78,7 @@ int send_request (int sd, int proto, const char *send_buffer, char *recv_buffer,
 int is_host (const char *);
 int is_addr (const char *);
 int resolve_host_or_addr (const char *, int);
+void host_or_die(const char *str);
 #define is_inet_addr(addr) resolve_host_or_addr(addr, AF_INET)
 #ifdef USE_IPV6
 #  define is_inet6_addr(addr) resolve_host_or_addr(addr, AF_INET6)
@@ -77,3 +91,15 @@ extern unsigned int socket_timeout;
 extern int econn_refuse_state;
 extern int was_refused;
 extern int address_family;
+
+/* SSL-Related functionality */
+#ifdef HAVE_SSL
+/* maybe this could be merged with the above np_net_connect, via some flags */
+int np_net_ssl_init(int sd);
+void np_net_ssl_cleanup();
+int np_net_ssl_write(const void *buf, int num);
+int np_net_ssl_read(void *buf, int num);
+int np_net_ssl_check_cert(int days_till_exp);
+#endif /* HAVE_SSL */
+
+#endif /* _NETUTILS_H_ */
