@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: popen.h,v 1.3 2004/12/25 23:17:44 opensides Exp $
+ * $Id: popen.h,v 1.4 2005/05/01 20:12:03 seanius Exp $
  *
  ******************************************************************************/
 
@@ -9,7 +9,7 @@ int spclose (FILE *);
 RETSIGTYPE popen_timeout_alarm_handler (int);
 
 extern unsigned int timeout_interval;
-pid_t *childpid;
-int *child_stderr_array;
-FILE *child_process;
-FILE *child_stderr;
+pid_t *childpid=NULL;
+int *child_stderr_array=NULL;
+FILE *child_process=NULL;
+FILE *child_stderr=NULL;
