@@ -1,26 +1,44 @@
 /******************************************************************************
+*
+* Nagios urlize plugin
+*
+* License: GPL
+* Copyright (c) 2000-2006 nagios-plugins team
+*
+* Last Modified: $Date: 2006/10/19 23:53:28 $
+*
+* Description:
+*
+* This file contains the urlize plugin
+*
+*  This plugin wraps the text output of another command (plugin)
+*  in HTML <A> tags, thus displaying the plugin output in as a clickable link in
+*  the Nagios status screen.  The return status is the same as the invoked plugin.
+*
+* License Information:
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: urlize.c,v 1.18 2005/12/07 19:32:37 harpermann Exp $
+ $Id: urlize.c,v 1.21 2006/10/19 23:53:28 opensides Exp $
  
 ******************************************************************************/
 
 const char *progname = "urlize";
-const char *revision = "$Revision: 1.18 $";
-const char *copyright = "2000-2004";
+const char *revision = "$Revision: 1.21 $";
+const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -56,6 +74,12 @@ main (int argc, char **argv)
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
 
+	/* Need at least 2 args */
+	if (argc < 3) {
+		print_help();
+		exit (STATE_UNKNOWN);
+	}
+
 	while (1) {
 		c = getopt_long (argc, argv, "+hVu:", longopts, &option);
 		
@@ -149,27 +173,25 @@ print_help (void)
 	printf ("Copyright (c) 2000 Karl DeBisschop <kdebisschop@users.sourceforge.net>\n");
 	printf (COPYRIGHT, copyright, email);
 
-	printf (_("\n\
-This plugin wraps the text output of another command (plugin) in HTML\n\
-<A> tags, thus displaying the plugin output in as a clickable link in\n\
-the Nagios status screen.  The return status is the same as the invoked\n\
-plugin.\n\n"));
+	printf ("%s\n", _("This plugin wraps the text output of another command (plugin)"));
+  printf ("%s\n", _("in HTML <A> tags, thus displaying the plugin output in as a clickable link in"));
+  printf ("%s\n", _("the Nagios status screen.  The return status is the same as the invoked plugin."));
+
+  printf ("\n\n");
 
 	print_usage ();
 
-	printf (_("\n\
-Pay close attention to quoting to ensure that the shell passes the expected\n\
-data to the plugin. For example, in:\n\
-\n\
-    urlize http://example.com/ check_http -H example.com -r 'two words'\n\
-\n\
-the shell will remove the single quotes and urlize will see:\n\
-\n\
-    urlize http://example.com/ check_http -H example.com -r two words\n\
-\n\
-You probably want:\n\
-\n\
-    urlize http://example.com/ \"check_http -H example.com -r 'two words'\"\n"));
+  printf (_(UT_HELP_VRSN));
+
+  printf ("\n");
+  printf ("%s\n", _("Examples:"));
+	printf ("%s\n", _("Pay close attention to quoting to ensure that the shell passes the expected"));
+  printf ("%s\n\n", _("data to the plugin. For example, in:"));
+  printf (" %s\n\n", _("urlize http://example.com/ check_http -H example.com -r 'two words'"));
+  printf ("    %s\n", _("the shell will remove the single quotes and urlize will see:"));
+  printf (" %s\n\n", _("urlize http://example.com/ check_http -H example.com -r two words"));
+  printf ("    %s\n\n", _("You probably want:"));
+  printf (" %s\n", _("urlize http://example.com/ \"check_http -H example.com -r 'two words'\""));
 
 	printf (_(UT_SUPPORT));
 }
@@ -179,5 +201,6 @@ You probably want:\n\
 void
 print_usage (void)
 {
-	printf ("Usage:\n %s <url> <plugin> <arg1> ... <argN>\n", progname);
+  printf (_("Usage:"));
+	printf ("%s <url> <plugin> <arg1> ... <argN>\n", progname);
 }
