@@ -13,14 +13,16 @@ in order to resist overflow attacks. In addition, a few functions are
 provided to standardize version and error reporting across the entire
 suite of plugins. */
 
+/* now some functions etc are being defined in ../lib/utils_base.c */
+#include "utils_base.h"
+
 /* Standardize version information, termination */
 
-/* $Id: utils.h,v 1.28 2006/03/29 16:33:36 tonvoon Exp $ */
+/* $Id: utils.h,v 1.32 2006/09/02 20:41:18 seanius Exp $ */
 
 void support (void);
 char *clean_revstring (const char *);
 void print_revision (const char *, const char *);
-void die (int, const char *, ...) __attribute__((noreturn,format(printf, 2, 3)));
 
 /* Handle timeouts */
 
@@ -58,28 +60,6 @@ struct timeval {
 };
 #endif
 
-#define OUTSIDE 0
-#define INSIDE  1
-
-typedef struct range_struct {
-	double	start;
-	int	start_infinity;		/* FALSE (default) or TRUE */
-	double	end;
-	int	end_infinity;
-	int	alert_on;		/* OUTSIDE (default) or INSIDE */
-	} range;
-
-typedef struct thresholds_struct {
-	range	*warning;
-	range	*critical;
-	} thresholds;
-
-range *parse_range_string (char *);
-int _set_thresholds(thresholds **, char *, char *);
-void set_thresholds(thresholds **, char *, char *);
-int check_range(double, range *);
-int get_status(double, thresholds *);
-
 #ifndef HAVE_GETTIMEOFDAY
 int gettimeofday(struct timeval *, struct timezone *);
 #endif
@@ -132,8 +112,6 @@ char *fperfdata (const char *,
  int,
  double);
 
-char *np_escaped_string (const char *);
-
 /* The idea here is that, although not every plugin will use all of these, 
    most will or should.  Therefore, for consistency, these very common 
    options should have only these meanings throughout the overall suite */
